import 'package:webview_flutter/webview_flutter.dart';
import 'package:flutter/material.dart';

import 'dart:convert';
import 'dart:io' show Platform;
import 'package:flutter/foundation.dart' show kIsWeb;
import 'package:svgator_player_flutter/svgator_player_flutter.dart';

class TestRobot extends StatefulWidget {
    final double? width;
    final double? height;
    
    final Function? onMessage;
    

    TestRobot({
        Key? key,
        this.width,
        this.height,
      
        this.onMessage,
      
    }): super(key: key);

  @override
  TestRobotState createState() => new TestRobotState();
}

class TestRobotState extends State<TestRobot> {
  final _key = UniqueKey();
  
  WebViewController? _SVGatorController;
  void runCommand(String command, int? param) {
      SVGatorPlayer.runCommand(_SVGatorController, command, param);
  }
  

  @override
  Widget build(BuildContext context) {
    if (kIsWeb || (!Platform.isAndroid && !Platform.isIOS)) {
      debugPrint("SVGator's Flutter animations run only on Android or iOS!");
      return SizedBox.shrink();
    }
    return Container(
        width: this.widget.width,
        height: this.widget.height,
        child: WebView(
          key: _key,
          javascriptMode: JavascriptMode.unrestricted,
          initialUrl: 'about:blank',
          
          javascriptChannels: <JavascriptChannel>{
            JavascriptChannel(
              name: 'SVGatorFlutterChannel',
              onMessageReceived: (JavascriptMessage message) {
                if (widget.onMessage != null) {
                  widget.onMessage?.call(message.message);
                }
              },
            )
          },
          
          onWebViewCreated: (WebViewController webViewController) {
            
            _SVGatorController = webViewController;
            
            _loadHtmlFromAssets(webViewController);
          },
          onPageFinished: (String url) {
            if (url == 'about:blank') {
              return;
            }
            
            _SVGatorController?.evaluateJavascript(SVGatorPlayer.initPlayer());
            
          },
        )
    );
  }

  _loadHtmlFromAssets(webViewController) async {
    String Svg = "<svg cache-id=\"f980417687fc460891c91873f31ff308\" id=\"eAhZY4D5jNs1\" xmlns=\"http:\/\/www.w3.org\/2000\/svg\" xmlns:xlink=\"http:\/\/www.w3.org\/1999\/xlink\" viewBox=\"0 0 200 130\" shape-rendering=\"geometricPrecision\" text-rendering=\"geometricPrecision\" style=\"background-color:#000\"><defs><linearGradient id=\"eAhZY4D5jNs14-fill\" x1=\"0\" y1=\"0.5\" x2=\"1\" y2=\"0.5\" spreadMethod=\"pad\" gradientUnits=\"objectBoundingBox\" gradientTransform=\"translate(0 0)\"><stop id=\"eAhZY4D5jNs14-fill-0\" offset=\"0%\" stop-color=\"#1c9500\"\/><stop id=\"eAhZY4D5jNs14-fill-1\" offset=\"100%\" stop-color=\"#082751\"\/><\/linearGradient><radialGradient id=\"eAhZY4D5jNs16-fill\" cx=\"0\" cy=\"0\" r=\"35.6\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(-29.165202 98.615406)\"><stop id=\"eAhZY4D5jNs16-fill-0\" offset=\"0%\" stop-color=\"rgba(83,95,120,0.3)\"\/><stop id=\"eAhZY4D5jNs16-fill-1\" offset=\"100%\" stop-color=\"rgba(255,255,255,0)\"\/><\/radialGradient><radialGradient id=\"eAhZY4D5jNs17-fill\" cx=\"0\" cy=\"0\" r=\"35.6\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(-29.165202 98.615406)\"><stop id=\"eAhZY4D5jNs17-fill-0\" offset=\"0%\" stop-color=\"rgba(83,95,120,0.3)\"\/><stop id=\"eAhZY4D5jNs17-fill-1\" offset=\"100%\" stop-color=\"rgba(255,255,255,0)\"\/><\/radialGradient><radialGradient id=\"eAhZY4D5jNs19-fill\" cx=\"0\" cy=\"0\" r=\"35.6\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(51.119487 82.350999)\"><stop id=\"eAhZY4D5jNs19-fill-0\" offset=\"0%\" stop-color=\"rgba(83,95,120,0.6)\"\/><stop id=\"eAhZY4D5jNs19-fill-1\" offset=\"100%\" stop-color=\"rgba(255,255,255,0)\"\/><\/radialGradient><radialGradient id=\"eAhZY4D5jNs20-fill\" cx=\"0\" cy=\"0\" r=\"35.6\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(79.436175 84.195395)\"><stop id=\"eAhZY4D5jNs20-fill-0\" offset=\"0%\" stop-color=\"rgba(83,95,120,0.6)\"\/><stop id=\"eAhZY4D5jNs20-fill-1\" offset=\"100%\" stop-color=\"rgba(255,255,255,0)\"\/><\/radialGradient><radialGradient id=\"eAhZY4D5jNs23-fill\" cx=\"0\" cy=\"0\" r=\"18.99\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(0 0)\"><stop id=\"eAhZY4D5jNs23-fill-0\" offset=\"0%\" stop-color=\"#3e4c68\"\/><stop id=\"eAhZY4D5jNs23-fill-1\" offset=\"100%\" stop-color=\"rgba(230,250,255,0)\"\/><\/radialGradient><radialGradient id=\"eAhZY4D5jNs25-fill\" cx=\"0\" cy=\"0\" r=\"18.99\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(0 0)\"><stop id=\"eAhZY4D5jNs25-fill-0\" offset=\"0%\" stop-color=\"#3e4c68\"\/><stop id=\"eAhZY4D5jNs25-fill-1\" offset=\"100%\" stop-color=\"rgba(230,250,255,0)\"\/><\/radialGradient><radialGradient id=\"eAhZY4D5jNs27-fill\" cx=\"0\" cy=\"0\" r=\"18.99\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(0 0)\"><stop id=\"eAhZY4D5jNs27-fill-0\" offset=\"0%\" stop-color=\"#3e4c68\"\/><stop id=\"eAhZY4D5jNs27-fill-1\" offset=\"100%\" stop-color=\"rgba(230,250,255,0)\"\/><\/radialGradient><linearGradient id=\"eAhZY4D5jNs31-fill\" x1=\"128.019976\" y1=\"90.1\" x2=\"111.029976\" y2=\"97.14\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(0 0)\"><stop id=\"eAhZY4D5jNs31-fill-0\" offset=\"0%\" stop-color=\"#fff\"\/><stop id=\"eAhZY4D5jNs31-fill-1\" offset=\"67%\" stop-color=\"#d0ddeb\"\/><stop id=\"eAhZY4D5jNs31-fill-2\" offset=\"100%\" stop-color=\"#6390b8\"\/><\/linearGradient><linearGradient id=\"eAhZY4D5jNs31-stroke\" x1=\"116.99\" y1=\"112.06\" x2=\"116.99\" y2=\"75.02\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(0 0)\"><stop id=\"eAhZY4D5jNs31-stroke-0\" offset=\"18%\" stop-color=\"#628fb7\"\/><stop id=\"eAhZY4D5jNs31-stroke-1\" offset=\"100%\" stop-color=\"#cfdeef\"\/><\/linearGradient><radialGradient id=\"eAhZY4D5jNs32-fill\" cx=\"0\" cy=\"0\" r=\"13.1\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(117.869976 93.54)\"><stop id=\"eAhZY4D5jNs32-fill-0\" offset=\"0%\" stop-color=\"#fff\"\/><stop id=\"eAhZY4D5jNs32-fill-1\" offset=\"100%\" stop-color=\"rgba(255,255,255,0.3)\"\/><\/radialGradient><linearGradient id=\"eAhZY4D5jNs33-fill\" x1=\"120.419976\" y1=\"111.7\" x2=\"120.419976\" y2=\"75.37\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(0 0)\"><stop id=\"eAhZY4D5jNs33-fill-0\" offset=\"0%\" stop-color=\"#9ab7d1\"\/><stop id=\"eAhZY4D5jNs33-fill-1\" offset=\"29%\" stop-color=\"#d0ddeb\"\/><stop id=\"eAhZY4D5jNs33-fill-2\" offset=\"87%\" stop-color=\"#fff\"\/><stop id=\"eAhZY4D5jNs33-fill-3\" offset=\"100%\" stop-color=\"#dfe8f1\"\/><\/linearGradient><linearGradient id=\"eAhZY4D5jNs33-stroke\" x1=\"120.42\" y1=\"112.06\" x2=\"120.42\" y2=\"75.02\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(0 0)\"><stop id=\"eAhZY4D5jNs33-stroke-0\" offset=\"0%\" stop-color=\"#628fb7\"\/><stop id=\"eAhZY4D5jNs33-stroke-1\" offset=\"67%\" stop-color=\"#cbdae9\"\/><stop id=\"eAhZY4D5jNs33-stroke-2\" offset=\"100%\" stop-color=\"#d1def0\"\/><\/linearGradient><linearGradient id=\"eAhZY4D5jNs45-fill\" x1=\"128.019976\" y1=\"90.1\" x2=\"111.029976\" y2=\"97.14\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(0 0)\"><stop id=\"eAhZY4D5jNs45-fill-0\" offset=\"0%\" stop-color=\"#fff\"\/><stop id=\"eAhZY4D5jNs45-fill-1\" offset=\"67%\" stop-color=\"#d0ddeb\"\/><stop id=\"eAhZY4D5jNs45-fill-2\" offset=\"100%\" stop-color=\"#6390b8\"\/><\/linearGradient><linearGradient id=\"eAhZY4D5jNs45-stroke\" x1=\"116.99\" y1=\"112.06\" x2=\"116.99\" y2=\"75.02\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(0 0)\"><stop id=\"eAhZY4D5jNs45-stroke-0\" offset=\"18%\" stop-color=\"#628fb7\"\/><stop id=\"eAhZY4D5jNs45-stroke-1\" offset=\"100%\" stop-color=\"#cfdeef\"\/><\/linearGradient><radialGradient id=\"eAhZY4D5jNs46-fill\" cx=\"0\" cy=\"0\" r=\"13.1\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(117.869976 93.54)\"><stop id=\"eAhZY4D5jNs46-fill-0\" offset=\"0%\" stop-color=\"#fff\"\/><stop id=\"eAhZY4D5jNs46-fill-1\" offset=\"100%\" stop-color=\"rgba(255,255,255,0.3)\"\/><\/radialGradient><linearGradient id=\"eAhZY4D5jNs47-fill\" x1=\"120.419976\" y1=\"111.7\" x2=\"120.419976\" y2=\"75.37\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(0 0)\"><stop id=\"eAhZY4D5jNs47-fill-0\" offset=\"0%\" stop-color=\"#9ab7d1\"\/><stop id=\"eAhZY4D5jNs47-fill-1\" offset=\"29%\" stop-color=\"#d0ddeb\"\/><stop id=\"eAhZY4D5jNs47-fill-2\" offset=\"87%\" stop-color=\"#fff\"\/><stop id=\"eAhZY4D5jNs47-fill-3\" offset=\"100%\" stop-color=\"#dfe8f1\"\/><\/linearGradient><linearGradient id=\"eAhZY4D5jNs47-stroke\" x1=\"120.42\" y1=\"112.06\" x2=\"120.42\" y2=\"75.02\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(0 0)\"><stop id=\"eAhZY4D5jNs47-stroke-0\" offset=\"0%\" stop-color=\"#628fb7\"\/><stop id=\"eAhZY4D5jNs47-stroke-1\" offset=\"67%\" stop-color=\"#cbdae9\"\/><stop id=\"eAhZY4D5jNs47-stroke-2\" offset=\"100%\" stop-color=\"#d1def0\"\/><\/linearGradient><radialGradient id=\"eAhZY4D5jNs57-fill\" cx=\"0\" cy=\"0\" r=\"32.46\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(140.11 91.45)\"><stop id=\"eAhZY4D5jNs57-fill-0\" offset=\"0%\" stop-color=\"#fff\"\/><stop id=\"eAhZY4D5jNs57-fill-1\" offset=\"36%\" stop-color=\"#f5f8fb\"\/><stop id=\"eAhZY4D5jNs57-fill-2\" offset=\"67%\" stop-color=\"#d0ddeb\"\/><stop id=\"eAhZY4D5jNs57-fill-3\" offset=\"100%\" stop-color=\"#6390b8\"\/><\/radialGradient><linearGradient id=\"eAhZY4D5jNs57-stroke\" x1=\"140\" y1=\"122\" x2=\"140\" y2=\"65.08\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(0 0)\"><stop id=\"eAhZY4D5jNs57-stroke-0\" offset=\"0%\" stop-color=\"#6390b8\"\/><stop id=\"eAhZY4D5jNs57-stroke-1\" offset=\"100%\" stop-color=\"#cfdeef\"\/><\/linearGradient><linearGradient id=\"eAhZY4D5jNs61-fill\" x1=\"140\" y1=\"109.12\" x2=\"140\" y2=\"96.32\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(0 0)\"><stop id=\"eAhZY4D5jNs61-fill-0\" offset=\"0%\" stop-color=\"#fff\"\/><stop id=\"eAhZY4D5jNs61-fill-1\" offset=\"36%\" stop-color=\"#f5f8fb\"\/><stop id=\"eAhZY4D5jNs61-fill-2\" offset=\"67%\" stop-color=\"#d0ddeb\"\/><stop id=\"eAhZY4D5jNs61-fill-3\" offset=\"100%\" stop-color=\"#9ab7d1\"\/><\/linearGradient><radialGradient id=\"eAhZY4D5jNs66-fill\" cx=\"0\" cy=\"0\" r=\"18.5\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(140.24 96.08)\"><stop id=\"eAhZY4D5jNs66-fill-0\" offset=\"0%\" stop-color=\"#1d5896\"\/><stop id=\"eAhZY4D5jNs66-fill-1\" offset=\"16%\" stop-color=\"#184e89\"\/><stop id=\"eAhZY4D5jNs66-fill-2\" offset=\"47%\" stop-color=\"#0c3565\"\/><stop id=\"eAhZY4D5jNs66-fill-3\" offset=\"88%\" stop-color=\"#000d2d\"\/><stop id=\"eAhZY4D5jNs66-fill-4\" offset=\"100%\" stop-color=\"#00001b\"\/><\/radialGradient><radialGradient id=\"eAhZY4D5jNs72-fill\" cx=\"0\" cy=\"0\" r=\"18.99\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(0 0)\"><stop id=\"eAhZY4D5jNs72-fill-0\" offset=\"28%\" stop-color=\"#3e4c68\"\/><stop id=\"eAhZY4D5jNs72-fill-1\" offset=\"43%\" stop-color=\"rgba(37,71,112,0.5)\"\/><stop id=\"eAhZY4D5jNs72-fill-2\" offset=\"69%\" stop-color=\"rgba(76,107,151,0.2)\"\/><stop id=\"eAhZY4D5jNs72-fill-3\" offset=\"100%\" stop-color=\"rgba(230,250,255,0)\"\/><\/radialGradient><radialGradient id=\"eAhZY4D5jNs73-fill\" cx=\"0\" cy=\"0\" r=\"55.74\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(142.389976 61.64)\"><stop id=\"eAhZY4D5jNs73-fill-0\" offset=\"0%\" stop-color=\"#194272\"\/><stop id=\"eAhZY4D5jNs73-fill-1\" offset=\"100%\" stop-color=\"#000d28\"\/><\/radialGradient><radialGradient id=\"eAhZY4D5jNs74-fill\" cx=\"0\" cy=\"0\" r=\"33.35\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(140.099976 54.39)\"><stop id=\"eAhZY4D5jNs74-fill-0\" offset=\"0%\" stop-color=\"#fff\"\/><stop id=\"eAhZY4D5jNs74-fill-1\" offset=\"26%\" stop-color=\"#f7f9fc\"\/><stop id=\"eAhZY4D5jNs74-fill-2\" offset=\"67%\" stop-color=\"#d0ddeb\"\/><stop id=\"eAhZY4D5jNs74-fill-3\" offset=\"100%\" stop-color=\"#8fafcc\"\/><\/radialGradient><linearGradient id=\"eAhZY4D5jNs75-stroke\" x1=\"110.52\" y1=\"47.4\" x2=\"169.48\" y2=\"47.4\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(0 0)\"><stop id=\"eAhZY4D5jNs75-stroke-0\" offset=\"0%\" stop-color=\"#e8eef5\"\/><stop id=\"eAhZY4D5jNs75-stroke-1\" offset=\"40%\" stop-color=\"#fff\"\/><stop id=\"eAhZY4D5jNs75-stroke-2\" offset=\"60%\" stop-color=\"#fff\"\/><stop id=\"eAhZY4D5jNs75-stroke-3\" offset=\"100%\" stop-color=\"#e8eef5\"\/><\/linearGradient><linearGradient id=\"eAhZY4D5jNs76-stroke\" x1=\"170.660215\" y1=\"48.57\" x2=\"109.350215\" y2=\"48.57\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(0 0)\"><stop id=\"eAhZY4D5jNs76-stroke-0\" offset=\"1%\" stop-color=\"#b4c7dc\"\/><stop id=\"eAhZY4D5jNs76-stroke-1\" offset=\"10%\" stop-color=\"#255b96\"\/><stop id=\"eAhZY4D5jNs76-stroke-2\" offset=\"50%\" stop-color=\"#d7e1ec\"\/><stop id=\"eAhZY4D5jNs76-stroke-3\" offset=\"90%\" stop-color=\"#255b96\"\/><stop id=\"eAhZY4D5jNs76-stroke-4\" offset=\"99%\" stop-color=\"#b4c7dc\"\/><\/linearGradient><linearGradient id=\"eAhZY4D5jNs78-fill\" x1=\"140.010013\" y1=\"75.307799\" x2=\"140.010013\" y2=\"55.142399\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(0 0)\"><stop id=\"eAhZY4D5jNs78-fill-0\" offset=\"18%\" stop-color=\"#fff\"\/><stop id=\"eAhZY4D5jNs78-fill-1\" offset=\"57%\" stop-color=\"#d6e1ee\"\/><\/linearGradient><radialGradient id=\"eAhZY4D5jNs79-fill\" cx=\"0\" cy=\"0\" r=\"40.76\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(140 58.7)\"><stop id=\"eAhZY4D5jNs79-fill-0\" offset=\"0%\" stop-color=\"#1d5896\"\/><stop id=\"eAhZY4D5jNs79-fill-1\" offset=\"16%\" stop-color=\"#184e89\"\/><stop id=\"eAhZY4D5jNs79-fill-2\" offset=\"47%\" stop-color=\"#0c3565\"\/><stop id=\"eAhZY4D5jNs79-fill-3\" offset=\"88%\" stop-color=\"#000d2d\"\/><stop id=\"eAhZY4D5jNs79-fill-4\" offset=\"100%\" stop-color=\"#00001b\"\/><\/radialGradient><radialGradient id=\"eAhZY4D5jNs80-fill\" cx=\"0\" cy=\"0\" r=\"40.88\" spreadMethod=\"pad\" gradientUnits=\"userSpaceOnUse\" gradientTransform=\"translate(139.27921 60.207006)\"><stop id=\"eAhZY4D5jNs80-fill-0\" offset=\"0%\" stop-color=\"#2a65a3\"\/><stop id=\"eAhZY4D5jNs80-fill-1\" offset=\"51%\" stop-color=\"#194272\"\/><stop id=\"eAhZY4D5jNs80-fill-2\" offset=\"100%\" stop-color=\"#000d28\"\/><\/radialGradient><radialGradient id=\"eAhZY4D5jNs84-fill\" cx=\"0\" cy=\"0\" r=\"0.5\" spreadMethod=\"pad\" gradientUnits=\"objectBoundingBox\" gradientTransform=\"translate(0.5 0.5)\"><stop id=\"eAhZY4D5jNs84-fill-0\" offset=\"0%\" stop-color=\"#970000\"\/><stop id=\"eAhZY4D5jNs84-fill-1\" offset=\"100%\" stop-color=\"#000\"\/><\/radialGradient><\/defs><g id=\"eAhZY4D5jNs4\" transform=\"translate(-39.812767 0)\" opacity=\"0\"><polygon id=\"eAhZY4D5jNs5\" points=\"60.96,70.61 69.44,75.51 60.96,80.4 60.96,70.61\" transform=\"translate(.02 37.769326)\" fill=\"none\" stroke=\"#9ab1eb\" stroke-width=\"1.24888\" stroke-miterlimit=\"10\"\/><circle id=\"eAhZY4D5jNs6\" r=\"3.75\" transform=\"translate(82.09 113.274326)\" fill=\"none\" stroke=\"#0055c6\" stroke-width=\"1.24888\" stroke-miterlimit=\"10\"\/><rect id=\"eAhZY4D5jNs7\" width=\"8.79\" height=\"8.79\" rx=\"0\" ry=\"0\" transform=\"translate(78.592966 108.879326)\" fill=\"none\" stroke=\"#0055c6\" stroke-width=\"1.24888\" stroke-miterlimit=\"10\"\/><path id=\"eAhZY4D5jNs8\" d=\"M45.79,88.41L55,97.57m-9.16,0L55,88.41\" transform=\"translate(.02 20.284326)\" fill=\"none\" stroke=\"#5b78af\" stroke-width=\"1.24888\" stroke-miterlimit=\"10\"\/><polygon id=\"eAhZY4D5jNs9\" points=\"198.8,87.42 195.38,96.6 205.04,94.96 198.8,87.42\" transform=\"translate(.02 21.264326)\" fill=\"none\" stroke=\"#0055c6\" stroke-width=\"1.24888\" stroke-miterlimit=\"10\"\/><circle id=\"eAhZY4D5jNs10\" r=\"4.88\" transform=\"translate(229.35 113.274326)\" fill=\"none\" stroke=\"#5b78af\" stroke-width=\"1.24888\" stroke-miterlimit=\"10\"\/><path id=\"eAhZY4D5jNs11\" d=\"M198.41,53.56l1.79,7.68m3-4.73l-7.69,1.79\" transform=\"translate(5.645 55.874326)\" fill=\"none\" stroke=\"#0055c6\" stroke-width=\"1.24888\" stroke-miterlimit=\"10\"\/><polygon id=\"eAhZY4D5jNs12\" points=\"215.53,79 209.37,77.24 209.13,70.83 215.15,68.63 219.11,73.68 215.53,79\" transform=\"translate(.02 39.459326)\" fill=\"none\" stroke=\"#9ab1eb\" stroke-width=\"1.24888\" stroke-miterlimit=\"10\"\/><\/g><rect width=\"47.637919\" height=\"46\" rx=\"0\" ry=\"0\" transform=\"matrix(4.198336 0 0 0.584503 0.000005 103.373952)\" fill=\"#fff\"\/><rect id=\"eAhZY4D5jNs14\" width=\"0\" height=\"13.115314\" rx=\"0\" ry=\"0\" transform=\"matrix(4.288406 0 0 0.334728-.025198 128.815909)\" fill=\"url(#eAhZY4D5jNs14-fill)\"\/><g transform=\"translate(-40-1.880005)\"><ellipse rx=\"49.05\" ry=\"9.02\" transform=\"translate(140 121.81)\" fill=\"url(#eAhZY4D5jNs16-fill)\"\/><ellipse rx=\"49.05\" ry=\"9.02\" transform=\"translate(140 121.81)\" fill=\"url(#eAhZY4D5jNs17-fill)\"\/><g><ellipse rx=\"21.68\" ry=\"12.13\" transform=\"translate(109.79 119.75)\" opacity=\"0.8\" fill=\"url(#eAhZY4D5jNs19-fill)\"\/><ellipse rx=\"21.68\" ry=\"12.13\" transform=\"translate(170.21 119.75)\" opacity=\"0.8\" fill=\"url(#eAhZY4D5jNs20-fill)\"\/><\/g><\/g><g id=\"eAhZY4D5jNs21\" transform=\"translate(-40-19.185138)\"><g transform=\"translate(.020046 5.261621)\"><circle id=\"eAhZY4D5jNs23\" r=\"18.99\" transform=\"matrix(1.569486 0 0 0.580533 140 114.274326)\" fill=\"url(#eAhZY4D5jNs23-fill)\"\/><g><circle id=\"eAhZY4D5jNs25\" r=\"18.99\" transform=\"matrix(.924397 0 0 0.341923 140 113.274326)\" opacity=\"0.2\" fill=\"url(#eAhZY4D5jNs25-fill)\"\/><\/g><g transform=\"matrix(-1 0 0 1 279.95991 0)\"><circle id=\"eAhZY4D5jNs27\" r=\"18.99\" transform=\"matrix(.924397 0 0 0.341923 140 113.274326)\" opacity=\"0.2\" fill=\"url(#eAhZY4D5jNs27-fill)\"\/><\/g><\/g><g transform=\"matrix(-1 0 0 1 279.95991 0)\"><g id=\"eAhZY4D5jNs29\"><rect width=\"18.33\" height=\"8.53\" rx=\"0\" ry=\"0\" transform=\"matrix(-1 0 0-1 132.47 97.81)\" fill=\"#3e4c68\"\/><path d=\"M118.53,111.73c-8.905077-10.491832-8.905077-25.888168,0-36.38l3.59.5v35.38Z\" fill=\"url(#eAhZY4D5jNs31-fill)\" stroke=\"url(#eAhZY4D5jNs31-stroke)\" stroke-width=\"0.623\" stroke-miterlimit=\"10\"\/><path d=\"M117.35,110.75v-34.42c.34-.45.68-.89,1.05-1.31v37c-.4-.38-.71-.83-1.05-1.27Z\" opacity=\"0.5\" fill=\"url(#eAhZY4D5jNs32-fill)\"\/><polygon points=\"118.71,75.37 122.12,75.85 122.12,111.23 118.71,111.7 118.71,75.37\" fill=\"url(#eAhZY4D5jNs33-fill)\" stroke=\"url(#eAhZY4D5jNs33-stroke)\" stroke-width=\"0.623\" stroke-miterlimit=\"10\"\/><g transform=\"matrix(.75 0 0 1 28.581645 0)\"><line id=\"eAhZY4D5jNs35\" x1=\"113.82\" y1=\"93.54\" x2=\"116.45\" y2=\"93.54\" transform=\"matrix(.534926 0.734355-.808291 0.588783 128.923471-38.606776)\" opacity=\"0.902564\" fill=\"none\" stroke=\"#6a8aae\" stroke-linecap=\"round\" stroke-linejoin=\"round\"\/><line id=\"eAhZY4D5jNs36\" x1=\"113.82\" y1=\"93.54\" x2=\"116.45\" y2=\"93.54\" transform=\"matrix(.59985-.013433 0.022389 0.999749 43.848477 1.572464)\" opacity=\"0.8\" fill=\"none\" stroke=\"#6a8aae\" stroke-linecap=\"round\" stroke-linejoin=\"round\"\/><line id=\"eAhZY4D5jNs37\" x1=\"113.82\" y1=\"93.54\" x2=\"116.45\" y2=\"93.54\" transform=\"matrix(.495484-.748457 0.833839 0.552008-20.220472 120.634309)\" opacity=\"0.697436\" fill=\"none\" stroke=\"#6a8aae\" stroke-linecap=\"round\" stroke-linejoin=\"round\"\/><line id=\"eAhZY4D5jNs38\" x1=\"113.82\" y1=\"93.54\" x2=\"116.45\" y2=\"93.54\" transform=\"matrix(.34202-.939693 0.939693 0.34202-13.716018 160.304277)\" opacity=\"0\" fill=\"none\" stroke=\"#6a8aae\" stroke-linecap=\"round\" stroke-linejoin=\"round\"\/><line id=\"eAhZY4D5jNs39\" x1=\"113.82\" y1=\"93.54\" x2=\"116.45\" y2=\"93.54\" transform=\"matrix(.34202-.939693 0.939693 0.34202-13.716018 160.304277)\" opacity=\"0\" fill=\"none\" stroke=\"#6a8aae\" stroke-linecap=\"round\" stroke-linejoin=\"round\"\/><line id=\"eAhZY4D5jNs40\" x1=\"113.82\" y1=\"93.54\" x2=\"116.45\" y2=\"93.54\" transform=\"matrix(.34202-.939693 0.939693 0.34202-13.716018 160.304277)\" opacity=\"0\" fill=\"none\" stroke=\"#6a8aae\" stroke-linecap=\"round\" stroke-linejoin=\"round\"\/><line id=\"eAhZY4D5jNs41\" x1=\"113.82\" y1=\"93.54\" x2=\"116.45\" y2=\"93.54\" transform=\"matrix(.34202-.939693 0.939693 0.34202-13.716018 160.304277)\" opacity=\"0\" fill=\"none\" stroke=\"#6a8aae\" stroke-linecap=\"round\" stroke-linejoin=\"round\"\/><\/g><\/g><\/g><g><g id=\"eAhZY4D5jNs43\"><rect width=\"18.33\" height=\"8.53\" rx=\"0\" ry=\"0\" transform=\"matrix(-1 0 0-1 132.47 97.81)\" fill=\"#3e4c68\"\/><path d=\"M118.53,111.73c-8.905077-10.491832-8.905077-25.888168,0-36.38l3.59.5v35.38Z\" fill=\"url(#eAhZY4D5jNs45-fill)\" stroke=\"url(#eAhZY4D5jNs45-stroke)\" stroke-width=\"0.623\" stroke-miterlimit=\"10\"\/><path d=\"M117.35,110.75v-34.42c.34-.45.68-.89,1.05-1.31v37c-.4-.38-.71-.83-1.05-1.27Z\" opacity=\"0.5\" fill=\"url(#eAhZY4D5jNs46-fill)\"\/><polygon points=\"118.71,75.37 122.12,75.85 122.12,111.23 118.71,111.7 118.71,75.37\" fill=\"url(#eAhZY4D5jNs47-fill)\" stroke=\"url(#eAhZY4D5jNs47-stroke)\" stroke-width=\"0.623\" stroke-miterlimit=\"10\"\/><g transform=\"matrix(.75 0 0 1 28.581645 0)\"><line id=\"eAhZY4D5jNs49\" x1=\"113.82\" y1=\"93.54\" x2=\"116.45\" y2=\"93.54\" transform=\"matrix(.534926 0.734355-.808291 0.588783 128.923471-38.606776)\" opacity=\"0.902564\" fill=\"none\" stroke=\"#6a8aae\" stroke-linecap=\"round\" stroke-linejoin=\"round\"\/><line id=\"eAhZY4D5jNs50\" x1=\"113.82\" y1=\"93.54\" x2=\"116.45\" y2=\"93.54\" transform=\"matrix(.59985-.013433 0.022389 0.999749 43.848477 1.572464)\" opacity=\"0.8\" fill=\"none\" stroke=\"#6a8aae\" stroke-linecap=\"round\" stroke-linejoin=\"round\"\/><line id=\"eAhZY4D5jNs51\" x1=\"113.82\" y1=\"93.54\" x2=\"116.45\" y2=\"93.54\" transform=\"matrix(.495484-.748457 0.833839 0.552008-20.220472 120.634309)\" opacity=\"0.697436\" fill=\"none\" stroke=\"#6a8aae\" stroke-linecap=\"round\" stroke-linejoin=\"round\"\/><line id=\"eAhZY4D5jNs52\" x1=\"113.82\" y1=\"93.54\" x2=\"116.45\" y2=\"93.54\" transform=\"matrix(.34202-.939693 0.939693 0.34202-13.716018 160.304277)\" opacity=\"0\" fill=\"none\" stroke=\"#6a8aae\" stroke-linecap=\"round\" stroke-linejoin=\"round\"\/><line id=\"eAhZY4D5jNs53\" x1=\"113.82\" y1=\"93.54\" x2=\"116.45\" y2=\"93.54\" transform=\"matrix(.34202-.939693 0.939693 0.34202-13.716018 160.304277)\" opacity=\"0\" fill=\"none\" stroke=\"#6a8aae\" stroke-linecap=\"round\" stroke-linejoin=\"round\"\/><line id=\"eAhZY4D5jNs54\" x1=\"113.82\" y1=\"93.54\" x2=\"116.45\" y2=\"93.54\" transform=\"matrix(.34202-.939693 0.939693 0.34202-13.716018 160.304277)\" opacity=\"0\" fill=\"none\" stroke=\"#6a8aae\" stroke-linecap=\"round\" stroke-linejoin=\"round\"\/><line id=\"eAhZY4D5jNs55\" x1=\"113.82\" y1=\"93.54\" x2=\"116.45\" y2=\"93.54\" transform=\"matrix(.34202-.939693 0.939693 0.34202-13.716018 160.304277)\" opacity=\"0\" fill=\"none\" stroke=\"#6a8aae\" stroke-linecap=\"round\" stroke-linejoin=\"round\"\/><\/g><\/g><\/g><g id=\"eAhZY4D5jNs56\" opacity=\"0\"><path d=\"M140,121.69c-8.166534.01232-15.935613-3.523724-21.29-9.69v-36.87c5.345276-6.184509,13.115642-9.739035,21.29-9.739035s15.944724,3.554526,21.29,9.739035v36.87c-5.354387,6.166276-13.123466,9.70232-21.29,9.69Z\" fill=\"url(#eAhZY4D5jNs57-fill)\" stroke=\"url(#eAhZY4D5jNs57-stroke)\" stroke-width=\"0.623\" stroke-miterlimit=\"10\"\/><g><g><g><path d=\"M147.67,96.33c-5.058444,1.026552-10.271556,1.026552-15.33,0-1.63-.19-5.38,2.82-6.27,4.5v2.09c.941709,1.795066,2.233853,3.383043,3.8,4.67c1.21,1,5.35,1.53,10.13,1.53s8.93-.56,10.14-1.53c1.566147-1.286957,2.858291-2.874934,3.8-4.67v-2.09c-.89-1.68-4.64-4.69-6.27-4.5Z\" fill=\"url(#eAhZY4D5jNs61-fill)\" fill-rule=\"evenodd\"\/><\/g><path style=\"mix-blend-mode:multiply\" d=\"M161.6,100.1c-.88.69-5,1.65-7.66,1.8l-.67-.65v-1.08l.67.66c2.69-.15,6.78-1.11,7.66-1.8Z\" opacity=\"0.5\" fill=\"#255b96\" fill-rule=\"evenodd\"\/><path d=\"M161.6,101.12c-.88.69-5,1.65-7.66,1.8l-.67-.65v-1l.67.65c2.68-.15,6.78-1.11,7.66-1.8Z\" opacity=\"0.5\" fill=\"#fff\" fill-rule=\"evenodd\"\/><path style=\"mix-blend-mode:multiply\" d=\"M118.41,100.1c.88.69,5,1.65,7.66,1.8l.67-.65v-1.08l-.67.66c-2.69-.15-6.78-1.11-7.66-1.8Z\" opacity=\"0.5\" fill=\"#255b96\" fill-rule=\"evenodd\"\/><path d=\"M118.41,101.12c.88.69,5,1.65,7.66,1.8l.67-.65v-1l-.67.65c-2.68-.15-6.78-1.11-7.66-1.8Z\" opacity=\"0.5\" fill=\"#fff\" fill-rule=\"evenodd\"\/><\/g><path d=\"M147.61,96.33c-5.029472.906591-10.180528.906591-15.21,0-1.55-.16-5,2.65-5.66,3.85v2.09c.913165,1.569073,2.142498,2.931215,3.61,4c1.16.86,5.1,1.36,9.65,1.36s8.5-.5,9.66-1.36c1.467502-1.068785,2.696835-2.430927,3.61-4v-2.09c-.66-1.18-4.11-4.01-5.66-3.85Z\" fill=\"url(#eAhZY4D5jNs66-fill)\" fill-rule=\"evenodd\"\/><g><circle id=\"eAhZY4D5jNs68\" r=\"1.38\" transform=\"matrix(.5 0 0 0.5 146.64 101.97)\" opacity=\"0.2\" fill=\"#5af3ff\"\/><circle id=\"eAhZY4D5jNs69\" r=\"1.38\" transform=\"matrix(.5 0 0 0.5 133.37 101.97)\" opacity=\"0.2\" fill=\"#5af3ff\"\/><circle id=\"eAhZY4D5jNs70\" r=\"1.38\" transform=\"matrix(.5 0 0 0.5 140 102.23)\" opacity=\"0.2\" fill=\"#5af3ff\"\/><\/g><\/g><g id=\"eAhZY4D5jNs71\" transform=\"translate(0 3.000001)\"><circle id=\"eAhZY4D5jNs72\" r=\"18.99\" transform=\"matrix(1.569486 0 0 0.580533 140 80.088528)\" fill=\"url(#eAhZY4D5jNs72-fill)\"\/><path d=\"M168.89,60.1c0,0,5.08,1.15,4.42,4.67s-5.87,2.29-5.87,2.29h-54.88c0,0-5.21,1.23-5.87-2.29s4.42-4.67,4.42-4.67Z\" fill=\"url(#eAhZY4D5jNs73-fill)\"\/><path d=\"M140,84.85c-13.89,0-24.55-7.64-27.89-15.18-3.43-7.75-3-13.59-2.92-14.23c2.15-12.53,14.24-20.63,30.81-20.63s28.66,8.1,30.81,20.64c.06.63.51,6.47-2.92,14.22-3.34,7.54-14,15.18-27.89,15.18Z\" fill=\"url(#eAhZY4D5jNs74-fill)\" stroke=\"#b4c7dc\" stroke-width=\"0.622674\" stroke-miterlimit=\"10\"\/><path id=\"eAhZY4D5jNs75\" d=\"M169.17,51.52c0,0-4.1-8.24-29.17-8.24s-29.17,8.24-29.17,8.24\" transform=\"matrix(1 0 0 0.84048 0 8.535502)\" fill=\"none\" stroke=\"url(#eAhZY4D5jNs75-stroke)\" stroke-width=\"0.622674\" stroke-linecap=\"round\" stroke-linejoin=\"round\"\/><path id=\"eAhZY4D5jNs76\" d=\"M170.37,53.46c0,0-4-9.58-30.37-9.58s-30.37,9.58-30.37,9.58\" transform=\"matrix(1 0 0 0.84048 0 8.531344)\" fill=\"none\" stroke=\"url(#eAhZY4D5jNs76-stroke)\" stroke-width=\"0.622674\" stroke-miterlimit=\"10\"\/><g id=\"eAhZY4D5jNs77\" transform=\"translate(0 2)\"><path d=\"M140,70.77c-3.62,0-5,3.6-11.2,4.29-7.85.86-14.37-4.69-14.37-11.2-.138579-4.605601,3.401403-8.490732,8-8.78c5.35-.35,11.56,1,17.52,1s12.18-1.36,17.53-1c4.618426.263378,8.187507,4.156114,8.05,8.78c0,6.51-6.52,12.06-14.37,11.2-6.16-.69-7.53-4.29-11.16-4.29Z\" fill=\"url(#eAhZY4D5jNs78-fill)\"\/><path d=\"M140,56.75c-6.85,0-8.38-.8-16.76-.8-2.229138.066528-4.336656,1.031601-5.843355,2.675786s-2.284534,3.827753-2.156645,6.054214c.49,4.71,5.62,9.34,11.66,9.52s8.1-4.72,13.1-4.72s7.1,4.9,13.14,4.72s11.17-4.81,11.66-9.52c.127889-2.226461-.649947-4.410029-2.156645-6.054214s-3.614217-2.609258-5.843355-2.675786c-8.41.05-9.94.8-16.8.8Z\" fill=\"url(#eAhZY4D5jNs79-fill)\"\/><path d=\"M140,58.28c-6.67,0-8.15-.9-16.31-.9-4.31,0-8.36,3.92-7.92,8s5,8.2,10.86,8.36s7.81-4.65,13.37-4.65s7.5,4.81,13.38,4.65s10.4-4.14,10.86-8.36-3.61-8-7.92-8c-8.16,0-9.64.9-16.32.9Z\" fill=\"url(#eAhZY4D5jNs80-fill)\"\/><g id=\"eAhZY4D5jNs81\"><path id=\"eAhZY4D5jNs82\" d=\"M-2.3,0c0-1.270255,1.029745-2.3,2.3-2.3s2.3,1.029745,2.3,2.3-1.029745,2.3-2.3,2.3-2.3-1.029745-2.3-2.3Z\" transform=\"translate(153.79 65.210567)\" fill=\"#5aff94\"\/><path id=\"eAhZY4D5jNs83\" d=\"M-2.3,0c0-1.270255,1.029745-2.3,2.3-2.3s2.3,1.029745,2.3,2.3-1.029745,2.3-2.3,2.3-2.3-1.029745-2.3-2.3Z\" transform=\"translate(127.12 65.210567)\" fill=\"#5aff94\"\/><\/g><\/g><\/g><\/g><\/g><ellipse id=\"eAhZY4D5jNs84\" rx=\"9.75681\" ry=\"9.75681\" transform=\"translate(189.709137 11)\" fill=\"url(#eAhZY4D5jNs84-fill)\" stroke-width=\"0\"\/><script><![CDATA[${SVGatorPlayer.getPlayer("91c80d77")};(function(s,i,o,w,a,b){(a=document.getElementById(i.root)).svgatorPlayer={ready:(function(a){b=[];return function(c){return c?(b.push(c),a.svgatorPlayer):b}})(a)};w[o]=w[o]||{};w[o][s]=w[o][s]||[];w[o][s].push(i);})('91c80d77',{\"root\":\"eAhZY4D5jNs1\",\"animations\":[{\"elements\":{\"eAhZY4D5jNs4\":{\"opacity\":[{\"t\":400,\"v\":0,\"e\":[0.705,0,1,1]},{\"t\":2200,\"v\":1},{\"t\":6900,\"v\":1},{\"t\":8600,\"v\":0}]},\"eAhZY4D5jNs5\":{\"transform\":{\"data\":{\"t\":{\"x\":-65.2,\"y\":-75.505}},\"keys\":{\"o\":[{\"t\":1000,\"v\":{\"x\":65.22,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":2800,\"v\":{\"x\":65.248705,\"y\":26.5275,\"type\":\"corner\"},\"e\":[1,0]},{\"t\":3000,\"v\":{\"x\":82.987966,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":4800,\"v\":{\"x\":83.016671,\"y\":26.2775,\"type\":\"corner\"},\"e\":[1,0]},{\"t\":5000,\"v\":{\"x\":82.987966,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":6800,\"v\":{\"x\":83.016671,\"y\":26.2775,\"type\":\"corner\"},\"e\":[1,0]},{\"t\":7000,\"v\":{\"x\":82.987966,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":8800,\"v\":{\"x\":83.016671,\"y\":26.2775,\"type\":\"corner\"},\"e\":[1,0]}],\"r\":[{\"t\":1000,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":2800,\"v\":180,\"e\":[1,0]},{\"t\":3000,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":4800,\"v\":180,\"e\":[1,0]},{\"t\":5000,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":6800,\"v\":180,\"e\":[1,0]},{\"t\":7000,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":8800,\"v\":180,\"e\":[1,0]}],\"s\":[{\"t\":1000,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":2800,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]},{\"t\":3000,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":4800,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]},{\"t\":5000,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":6800,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]},{\"t\":7000,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":8800,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]}]}},\"opacity\":[{\"t\":1000,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":2800,\"v\":0,\"e\":[1,0]},{\"t\":3000,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":4800,\"v\":0,\"e\":[1,0]},{\"t\":5000,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":6800,\"v\":0,\"e\":[1,0]},{\"t\":7000,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":8800,\"v\":0,\"e\":[1,0]}]},\"eAhZY4D5jNs6\":{\"transform\":{\"keys\":{\"o\":[{\"t\":400,\"v\":{\"x\":82.09,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":2200,\"v\":{\"x\":82.118705,\"y\":25.955,\"type\":\"corner\"},\"e\":[1,0]},{\"t\":2400,\"v\":{\"x\":82.987966,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":4200,\"v\":{\"x\":83.016671,\"y\":26.2775,\"type\":\"corner\"},\"e\":[1,0]},{\"t\":4400,\"v\":{\"x\":82.987966,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":6200,\"v\":{\"x\":83.016671,\"y\":26.2775,\"type\":\"corner\"},\"e\":[1,0]},{\"t\":6400,\"v\":{\"x\":82.987966,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":8200,\"v\":{\"x\":83.016671,\"y\":26.2775,\"type\":\"corner\"},\"e\":[1,0]}],\"r\":[{\"t\":400,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":2200,\"v\":180,\"e\":[1,0]},{\"t\":2400,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":4200,\"v\":180,\"e\":[1,0]},{\"t\":4400,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":6200,\"v\":180,\"e\":[1,0]},{\"t\":6400,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":8200,\"v\":180,\"e\":[1,0]}],\"s\":[{\"t\":400,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":2200,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]},{\"t\":2400,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":4200,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]},{\"t\":4400,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":6200,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]},{\"t\":6400,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":8200,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]}]}},\"opacity\":[{\"t\":400,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":2200,\"v\":0,\"e\":[1,0]},{\"t\":2400,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":4200,\"v\":0,\"e\":[1,0]},{\"t\":4400,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":6200,\"v\":0,\"e\":[1,0]},{\"t\":6400,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":8200,\"v\":0,\"e\":[1,0]}]},\"eAhZY4D5jNs7\":{\"transform\":{\"data\":{\"t\":{\"x\":-4.395,\"y\":-4.395}},\"keys\":{\"o\":[{\"t\":1700,\"v\":{\"x\":82.987966,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":3500,\"v\":{\"x\":83.016671,\"y\":26.2775,\"type\":\"corner\"},\"e\":[1,0]},{\"t\":3700,\"v\":{\"x\":82.987966,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":5500,\"v\":{\"x\":83.016671,\"y\":26.2775,\"type\":\"corner\"},\"e\":[1,0]},{\"t\":5700,\"v\":{\"x\":82.987966,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":7500,\"v\":{\"x\":83.016671,\"y\":26.2775,\"type\":\"corner\"},\"e\":[1,0]},{\"t\":7700,\"v\":{\"x\":82.987966,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":9500,\"v\":{\"x\":83.016671,\"y\":26.2775,\"type\":\"corner\"},\"e\":[1,0]}],\"r\":[{\"t\":1700,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":3500,\"v\":180,\"e\":[1,0]},{\"t\":3700,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":5500,\"v\":180,\"e\":[1,0]},{\"t\":5700,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":7500,\"v\":180,\"e\":[1,0]},{\"t\":7700,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":9500,\"v\":180,\"e\":[1,0]}],\"s\":[{\"t\":1700,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":3500,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]},{\"t\":3700,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":5500,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]},{\"t\":5700,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":7500,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]},{\"t\":7700,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":9500,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]}]}},\"opacity\":[{\"t\":1700,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":3500,\"v\":0,\"e\":[1,0]},{\"t\":3700,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":5500,\"v\":0,\"e\":[1,0]},{\"t\":5700,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":7500,\"v\":0,\"e\":[1,0]},{\"t\":7700,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":9500,\"v\":0,\"e\":[1,0]}]},\"eAhZY4D5jNs8\":{\"transform\":{\"data\":{\"t\":{\"x\":-50.395,\"y\":-92.99}},\"keys\":{\"o\":[{\"t\":600,\"v\":{\"x\":50.415,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":2400,\"v\":{\"x\":50.443705,\"y\":26.37,\"type\":\"corner\"},\"e\":[1,0]},{\"t\":2600,\"v\":{\"x\":50.415,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":4400,\"v\":{\"x\":50.443705,\"y\":26.37,\"type\":\"corner\"},\"e\":[1,0]},{\"t\":4600,\"v\":{\"x\":50.415,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":6400,\"v\":{\"x\":50.443705,\"y\":26.37,\"type\":\"corner\"},\"e\":[1,0]},{\"t\":6600,\"v\":{\"x\":50.415,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":8400,\"v\":{\"x\":50.443705,\"y\":26.37,\"type\":\"corner\"},\"e\":[1,0]}],\"r\":[{\"t\":600,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":2400,\"v\":180,\"e\":[1,0]},{\"t\":2600,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":4400,\"v\":180,\"e\":[1,0]},{\"t\":4600,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":6400,\"v\":180,\"e\":[1,0]},{\"t\":6600,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":8400,\"v\":180,\"e\":[1,0]}],\"s\":[{\"t\":600,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":2400,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]},{\"t\":2600,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":4400,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]},{\"t\":4600,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":6400,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]},{\"t\":6600,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":8400,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]}]}},\"opacity\":[{\"t\":600,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":2400,\"v\":0,\"e\":[1,0]},{\"t\":2600,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":4400,\"v\":0,\"e\":[1,0]},{\"t\":4600,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":6400,\"v\":0,\"e\":[1,0]},{\"t\":6600,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":8400,\"v\":0,\"e\":[1,0]}]},\"eAhZY4D5jNs9\":{\"transform\":{\"data\":{\"t\":{\"x\":-200.21,\"y\":-92.01}},\"keys\":{\"o\":[{\"t\":1100,\"v\":{\"x\":200.23,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":2900,\"v\":{\"x\":200.258705,\"y\":24.08,\"type\":\"corner\"},\"e\":[1,0]},{\"t\":3100,\"v\":{\"x\":200.23,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":4900,\"v\":{\"x\":200.258705,\"y\":24.08,\"type\":\"corner\"},\"e\":[1,0]},{\"t\":5100,\"v\":{\"x\":200.23,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":6900,\"v\":{\"x\":200.258705,\"y\":24.08,\"type\":\"corner\"},\"e\":[1,0]},{\"t\":7100,\"v\":{\"x\":200.23,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":8900,\"v\":{\"x\":200.258705,\"y\":24.08,\"type\":\"corner\"}}],\"r\":[{\"t\":1100,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":2900,\"v\":180,\"e\":[1,0]},{\"t\":3100,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":4900,\"v\":180,\"e\":[1,0]},{\"t\":5100,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":6900,\"v\":180,\"e\":[1,0]},{\"t\":7100,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":8900,\"v\":180}],\"s\":[{\"t\":1100,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":2900,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]},{\"t\":3100,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":4900,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]},{\"t\":5100,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":6900,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]},{\"t\":7100,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":8900,\"v\":{\"x\":0.5,\"y\":0.5}}]}},\"opacity\":[{\"t\":1100,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":2900,\"v\":0,\"e\":[1,0]},{\"t\":3100,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":4900,\"v\":0,\"e\":[1,0]},{\"t\":5100,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":6900,\"v\":0,\"e\":[1,0]},{\"t\":7100,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":8900,\"v\":0}]},\"eAhZY4D5jNs10\":{\"transform\":{\"keys\":{\"o\":[{\"t\":800,\"v\":{\"x\":229.35,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":2600,\"v\":{\"x\":229.378705,\"y\":24.08,\"type\":\"corner\"},\"e\":[1,0]},{\"t\":2800,\"v\":{\"x\":229.35,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":4600,\"v\":{\"x\":229.378705,\"y\":24.08,\"type\":\"corner\"},\"e\":[1,0]},{\"t\":4800,\"v\":{\"x\":229.35,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":6600,\"v\":{\"x\":229.378705,\"y\":24.08,\"type\":\"corner\"},\"e\":[1,0]},{\"t\":6800,\"v\":{\"x\":229.35,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":8600,\"v\":{\"x\":229.378705,\"y\":24.08,\"type\":\"corner\"}}],\"r\":[{\"t\":800,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":2600,\"v\":180,\"e\":[1,0]},{\"t\":2800,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":4600,\"v\":180,\"e\":[1,0]},{\"t\":4800,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":6600,\"v\":180,\"e\":[1,0]},{\"t\":6800,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":8600,\"v\":180}],\"s\":[{\"t\":800,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":2600,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]},{\"t\":2800,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":4600,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]},{\"t\":4800,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":6600,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]},{\"t\":6800,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":8600,\"v\":{\"x\":0.5,\"y\":0.5}}]}},\"opacity\":[{\"t\":800,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":2600,\"v\":0,\"e\":[1,0]},{\"t\":2800,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":4600,\"v\":0,\"e\":[1,0]},{\"t\":4800,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":6600,\"v\":0,\"e\":[1,0]},{\"t\":6800,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":8600,\"v\":0}]},\"eAhZY4D5jNs11\":{\"transform\":{\"data\":{\"t\":{\"x\":-199.355,\"y\":-57.4}},\"keys\":{\"o\":[{\"t\":1800,\"v\":{\"x\":205,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":3600,\"v\":{\"x\":205,\"y\":24.08,\"type\":\"corner\"},\"e\":[1,0]},{\"t\":3800,\"v\":{\"x\":205,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":5600,\"v\":{\"x\":205,\"y\":24.08,\"type\":\"corner\"},\"e\":[1,0]},{\"t\":5800,\"v\":{\"x\":205,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.47,0,0.745,0.715]},{\"t\":7600,\"v\":{\"x\":205,\"y\":24.08,\"type\":\"corner\"}}],\"r\":[{\"t\":1800,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":3600,\"v\":180,\"e\":[1,0]},{\"t\":3800,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":5600,\"v\":180,\"e\":[1,0]},{\"t\":5800,\"v\":0,\"e\":[0.47,0,0.745,0.715]},{\"t\":7600,\"v\":180}],\"s\":[{\"t\":1800,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":3600,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]},{\"t\":3800,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":5600,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]},{\"t\":5800,\"v\":{\"x\":1,\"y\":1},\"e\":[0.47,0,0.745,0.715]},{\"t\":7600,\"v\":{\"x\":0.5,\"y\":0.5}}]}},\"opacity\":[{\"t\":1800,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":3600,\"v\":0,\"e\":[1,0]},{\"t\":3800,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":5600,\"v\":0,\"e\":[1,0]},{\"t\":5800,\"v\":1,\"e\":[0.47,0,0.745,0.715]},{\"t\":7600,\"v\":0}]},\"eAhZY4D5jNs12\":{\"transform\":{\"data\":{\"t\":{\"x\":-214.12,\"y\":-73.815}},\"keys\":{\"o\":[{\"t\":400,\"v\":{\"x\":214.14,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.42,0,1,1]},{\"t\":2200,\"v\":{\"x\":214.168705,\"y\":24.08,\"type\":\"corner\"},\"e\":[1,0]},{\"t\":2400,\"v\":{\"x\":214.14,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.42,0,1,1]},{\"t\":4200,\"v\":{\"x\":214.168705,\"y\":24.08,\"type\":\"corner\"},\"e\":[1,0]},{\"t\":4400,\"v\":{\"x\":214.14,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.42,0,1,1]},{\"t\":6200,\"v\":{\"x\":214.168705,\"y\":24.08,\"type\":\"corner\"},\"e\":[1,0]},{\"t\":6400,\"v\":{\"x\":214.14,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.42,0,1,1]},{\"t\":8200,\"v\":{\"x\":214.168705,\"y\":24.08,\"type\":\"corner\"}}],\"r\":[{\"t\":400,\"v\":0,\"e\":[0.42,0,1,1]},{\"t\":2200,\"v\":180,\"e\":[1,0]},{\"t\":2400,\"v\":0,\"e\":[0.42,0,1,1]},{\"t\":4200,\"v\":180,\"e\":[1,0]},{\"t\":4400,\"v\":0,\"e\":[0.42,0,1,1]},{\"t\":6200,\"v\":180,\"e\":[1,0]},{\"t\":6400,\"v\":0,\"e\":[0.42,0,1,1]},{\"t\":8200,\"v\":180}],\"s\":[{\"t\":400,\"v\":{\"x\":1,\"y\":1},\"e\":[0.42,0,1,1]},{\"t\":2200,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]},{\"t\":2400,\"v\":{\"x\":1,\"y\":1},\"e\":[0.42,0,1,1]},{\"t\":4200,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]},{\"t\":4400,\"v\":{\"x\":1,\"y\":1},\"e\":[0.42,0,1,1]},{\"t\":6200,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[1,0]},{\"t\":6400,\"v\":{\"x\":1,\"y\":1},\"e\":[0.42,0,1,1]},{\"t\":8200,\"v\":{\"x\":0.5,\"y\":0.5}}]}},\"opacity\":[{\"t\":400,\"v\":1,\"e\":[0.42,0,1,1]},{\"t\":2200,\"v\":0,\"e\":[1,0]},{\"t\":2400,\"v\":1,\"e\":[0.42,0,1,1]},{\"t\":4200,\"v\":0,\"e\":[1,0]},{\"t\":4400,\"v\":1,\"e\":[0.42,0,1,1]},{\"t\":6200,\"v\":0,\"e\":[1,0]},{\"t\":6400,\"v\":1,\"e\":[0.42,0,1,1]},{\"t\":8200,\"v\":0}]},\"eAhZY4D5jNs14\":{\"#size\":[{\"t\":0,\"v\":{\"width\":0,\"height\":13.115314}},{\"t\":10000,\"v\":{\"width\":46.640977,\"height\":3.554624}}]},\"eAhZY4D5jNs21\":{\"transform\":{\"data\":{\"o\":{\"x\":100.02,\"y\":99.089188,\"type\":\"corner\"},\"t\":{\"x\":-140.02,\"y\":-118.274326}},\"keys\":{\"s\":[{\"t\":390,\"v\":{\"x\":1,\"y\":1},\"e\":[0.42,0,0.215,1]},{\"t\":890,\"v\":{\"x\":0.969428,\"y\":0.969428},\"e\":[0.84,0.005,0.35,0.995]},{\"t\":2210,\"v\":{\"x\":1.061389,\"y\":1.061389},\"e\":[0.33,0.005,0.465,1]},{\"t\":3600,\"v\":{\"x\":1,\"y\":1},\"e\":[0.4,0.005,0.515,0.98]},{\"t\":4500,\"v\":{\"x\":1.028362,\"y\":1.028362},\"e\":[0.4,0.005,0.515,0.98]},{\"t\":5400,\"v\":{\"x\":1,\"y\":1},\"e\":[0.42,0,0.215,1]},{\"t\":6700,\"v\":{\"x\":1.02611,\"y\":1.02611},\"e\":[0.42,0,0.58,1]},{\"t\":7000,\"v\":{\"x\":1.034658,\"y\":1.034658},\"e\":[0.42,0,0.58,1]},{\"t\":7400,\"v\":{\"x\":1,\"y\":1}}]}}},\"eAhZY4D5jNs23\":{\"opacity\":[{\"t\":200,\"v\":1,\"e\":[0.23,1,0.345,1.5]},{\"t\":400,\"v\":0.33},{\"t\":8500,\"v\":0.33},{\"t\":9000,\"v\":1,\"e\":[0.23,1,0.345,1.5]}]},\"eAhZY4D5jNs25\":{\"transform\":{\"data\":{\"s\":{\"x\":0.924397,\"y\":0.341923}},\"keys\":{\"o\":[{\"t\":0,\"v\":{\"x\":140,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.645,0.045,0.345,1.34]},{\"t\":200,\"v\":{\"x\":111.575467,\"y\":112.79,\"type\":\"corner\"}},{\"t\":8500,\"v\":{\"x\":111.575467,\"y\":112.79,\"type\":\"corner\"}},{\"t\":9000,\"v\":{\"x\":140,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.645,0.045,0.345,1.34]}]}},\"opacity\":[{\"t\":0,\"v\":0.2,\"e\":[0.755,0.05,0.855,0.06]},{\"t\":200,\"v\":0.5},{\"t\":8500,\"v\":0.5},{\"t\":9000,\"v\":0.2,\"e\":[0.755,0.05,0.855,0.06]}]},\"eAhZY4D5jNs27\":{\"transform\":{\"data\":{\"s\":{\"x\":0.924397,\"y\":0.341923}},\"keys\":{\"o\":[{\"t\":0,\"v\":{\"x\":140,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.645,0.045,0.345,1.34]},{\"t\":200,\"v\":{\"x\":111.575467,\"y\":112.79,\"type\":\"corner\"}},{\"t\":8500,\"v\":{\"x\":111.575467,\"y\":112.79,\"type\":\"corner\"}},{\"t\":9000,\"v\":{\"x\":140,\"y\":113.274326,\"type\":\"corner\"},\"e\":[0.645,0.045,0.345,1.34]}]}},\"opacity\":[{\"t\":0,\"v\":0.2,\"e\":[0.755,0.05,0.855,0.06]},{\"t\":200,\"v\":0.5},{\"t\":8500,\"v\":0.5},{\"t\":9000,\"v\":0.2,\"e\":[0.755,0.05,0.855,0.06]}]},\"eAhZY4D5jNs29\":{\"transform\":{\"data\":{\"t\":{\"x\":-132.47,\"y\":-93.723625}},\"keys\":{\"o\":[{\"t\":0,\"v\":{\"x\":132.47,\"y\":93.723625,\"type\":\"corner\"},\"e\":[0.645,0.045,0.345,1.34]},{\"t\":200,\"v\":{\"x\":124.309999,\"y\":100.163628,\"type\":\"corner\"}},{\"t\":8500,\"v\":{\"x\":124.309999,\"y\":100.163628,\"type\":\"corner\"}},{\"t\":9000,\"v\":{\"x\":132.47,\"y\":93.723625,\"type\":\"corner\"},\"e\":[0.645,0.045,0.345,1.34]}]}}},\"eAhZY4D5jNs35\":{\"transform\":{\"data\":{\"t\":{\"x\":-113.456859,\"y\":-93.548494}},\"keys\":{\"o\":[{\"t\":390,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0.42,0,0.215,1]},{\"t\":890,\"v\":{\"x\":114,\"y\":97.61458,\"type\":\"corner\"},\"e\":[0.84,0.005,1,1]},{\"t\":1400,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":1590,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}}],\"r\":[{\"t\":390,\"v\":53.92933,\"e\":[0.42,0,0.215,1]},{\"t\":890,\"v\":34.605046,\"e\":[0.84,0.005,1,1]},{\"t\":1400,\"v\":53.92933},{\"t\":1590,\"v\":70}],\"s\":[{\"t\":390,\"v\":{\"x\":0.908528,\"y\":1},\"e\":[0.42,0,0.215,1]},{\"t\":890,\"v\":{\"x\":0.877199,\"y\":1},\"e\":[0.84,0.005,1,1]},{\"t\":1400,\"v\":{\"x\":0.908528,\"y\":1}},{\"t\":1590,\"v\":{\"x\":1,\"y\":1}}]}},\"opacity\":[{\"t\":1400,\"v\":0.902564},{\"t\":1580,\"v\":1},{\"t\":1590,\"v\":0}]},\"eAhZY4D5jNs36\":{\"transform\":{\"data\":{\"t\":{\"x\":-113.456859,\"y\":-93.548494}},\"keys\":{\"o\":[{\"t\":390,\"v\":{\"x\":114,\"y\":93.573387,\"type\":\"corner\"},\"e\":[0.42,0,0.215,1]},{\"t\":890,\"v\":{\"x\":114,\"y\":91.39736,\"type\":\"corner\"},\"e\":[0.84,0.005,1,1]},{\"t\":1400,\"v\":{\"x\":114,\"y\":93.573387,\"type\":\"corner\"}},{\"t\":1600,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":1690,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}}],\"r\":[{\"t\":390,\"v\":-1.282911,\"e\":[0.42,0,0.215,1]},{\"t\":890,\"v\":-20.607195,\"e\":[0.84,0.005,1,1]},{\"t\":1400,\"v\":-1.282911},{\"t\":1600,\"v\":53.92933},{\"t\":1690,\"v\":70}],\"s\":[{\"t\":390,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.42,0,0.215,1]},{\"t\":890,\"v\":{\"x\":0.71114,\"y\":1},\"e\":[0.84,0.005,1,1]},{\"t\":1400,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":1690,\"v\":{\"x\":1,\"y\":1}}]}},\"opacity\":[{\"t\":1400,\"v\":0.8},{\"t\":1680,\"v\":1},{\"t\":1690,\"v\":0}]},\"eAhZY4D5jNs37\":{\"transform\":{\"data\":{\"t\":{\"x\":-113.456859,\"y\":-93.548494}},\"keys\":{\"o\":[{\"t\":390,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"},\"e\":[0.42,0,0.215,1]},{\"t\":890,\"v\":{\"x\":113.39185,\"y\":86.344662,\"type\":\"corner\"},\"e\":[0.84,0.005,1,1]},{\"t\":1400,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":1700,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":1790,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}}],\"r\":[{\"t\":390,\"v\":-56.495152,\"e\":[0.42,0,0.215,1]},{\"t\":890,\"v\":-58.732873,\"e\":[0.84,0.005,1,1]},{\"t\":1400,\"v\":-56.495152},{\"t\":1700,\"v\":53.92933},{\"t\":1790,\"v\":70}],\"s\":[{\"t\":390,\"v\":{\"x\":0.897604,\"y\":1},\"e\":[0.42,0,0.215,1]},{\"t\":890,\"v\":{\"x\":0.954666,\"y\":1},\"e\":[0.84,0.005,1,1]},{\"t\":1400,\"v\":{\"x\":0.897604,\"y\":1}},{\"t\":1600,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":1790,\"v\":{\"x\":1,\"y\":1}}]}},\"opacity\":[{\"t\":1400,\"v\":0.697436},{\"t\":1780,\"v\":1},{\"t\":1790,\"v\":0}]},\"eAhZY4D5jNs38\":{\"transform\":{\"data\":{\"t\":{\"x\":-113.456859,\"y\":-93.548494}},\"keys\":{\"o\":[{\"t\":1400,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":1600,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":1800,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":1890,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":1900,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":2000,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":2200,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":2290,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":2300,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":2400,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":2600,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":2690,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":2700,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":2800,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":3000,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":3090,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":3100,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":3200,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":3400,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":3490,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":3500,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":3600,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":3800,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":3890,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":3900,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":4000,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":4200,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":4290,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":4300,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":4400,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":4600,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":4690,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":4700,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":4800,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":5000,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":5090,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":5100,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":5200,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":5400,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":5490,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":5500,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":5600,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":5800,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":5890,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":5900,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":6000,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":6200,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":6390,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}}],\"r\":[{\"t\":1400,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":1600,\"v\":-56.495152},{\"t\":1800,\"v\":53.92933},{\"t\":1890,\"v\":70},{\"t\":1900,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":2000,\"v\":-56.495152},{\"t\":2200,\"v\":53.92933},{\"t\":2290,\"v\":70},{\"t\":2300,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":2400,\"v\":-56.495152},{\"t\":2600,\"v\":53.92933},{\"t\":2690,\"v\":70},{\"t\":2700,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":2800,\"v\":-56.495152},{\"t\":3000,\"v\":53.92933},{\"t\":3090,\"v\":70},{\"t\":3100,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":3200,\"v\":-56.495152},{\"t\":3400,\"v\":53.92933},{\"t\":3490,\"v\":70},{\"t\":3500,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":3600,\"v\":-56.495152},{\"t\":3800,\"v\":53.92933},{\"t\":3890,\"v\":70},{\"t\":3900,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":4000,\"v\":-56.495152},{\"t\":4200,\"v\":53.92933},{\"t\":4290,\"v\":70},{\"t\":4300,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":4400,\"v\":-56.495152},{\"t\":4600,\"v\":53.92933},{\"t\":4690,\"v\":70},{\"t\":4700,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":4800,\"v\":-56.495152},{\"t\":5000,\"v\":53.92933},{\"t\":5090,\"v\":70},{\"t\":5100,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":5200,\"v\":-56.495152},{\"t\":5400,\"v\":53.92933},{\"t\":5490,\"v\":70},{\"t\":5500,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":5600,\"v\":-56.495152},{\"t\":5800,\"v\":53.92933},{\"t\":5890,\"v\":70},{\"t\":5900,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":6000,\"v\":-56.495152},{\"t\":6200,\"v\":53.92933},{\"t\":6390,\"v\":70}],\"s\":[{\"t\":1400,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":1700,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":1890,\"v\":{\"x\":1,\"y\":1}},{\"t\":1900,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":2100,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":2290,\"v\":{\"x\":1,\"y\":1}},{\"t\":2300,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":2500,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":2690,\"v\":{\"x\":1,\"y\":1}},{\"t\":2700,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":2900,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":3090,\"v\":{\"x\":1,\"y\":1}},{\"t\":3100,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":3300,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":3490,\"v\":{\"x\":1,\"y\":1}},{\"t\":3500,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":3700,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":3890,\"v\":{\"x\":1,\"y\":1}},{\"t\":3900,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":4100,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":4290,\"v\":{\"x\":1,\"y\":1}},{\"t\":4300,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":4500,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":4690,\"v\":{\"x\":1,\"y\":1}},{\"t\":4700,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":4900,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":5090,\"v\":{\"x\":1,\"y\":1}},{\"t\":5100,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":5300,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":5490,\"v\":{\"x\":1,\"y\":1}},{\"t\":5500,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":5700,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":5890,\"v\":{\"x\":1,\"y\":1}},{\"t\":5900,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":6100,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":6390,\"v\":{\"x\":1,\"y\":1}}]}},\"opacity\":[{\"t\":1400,\"v\":0},{\"t\":1410,\"v\":0.6},{\"t\":1880,\"v\":1},{\"t\":1890,\"v\":0},{\"t\":1900,\"v\":0},{\"t\":1910,\"v\":0.6},{\"t\":2280,\"v\":1},{\"t\":2290,\"v\":0},{\"t\":2300,\"v\":0},{\"t\":2310,\"v\":0.6},{\"t\":2680,\"v\":1},{\"t\":2690,\"v\":0},{\"t\":2700,\"v\":0},{\"t\":2710,\"v\":0.6},{\"t\":3080,\"v\":1},{\"t\":3090,\"v\":0},{\"t\":3100,\"v\":0},{\"t\":3110,\"v\":0.6},{\"t\":3480,\"v\":1},{\"t\":3490,\"v\":0},{\"t\":3500,\"v\":0},{\"t\":3510,\"v\":0.6},{\"t\":3880,\"v\":1},{\"t\":3890,\"v\":0},{\"t\":3900,\"v\":0},{\"t\":3910,\"v\":0.6},{\"t\":4280,\"v\":1},{\"t\":4290,\"v\":0},{\"t\":4300,\"v\":0},{\"t\":4310,\"v\":0.6},{\"t\":4680,\"v\":1},{\"t\":4690,\"v\":0},{\"t\":4700,\"v\":0},{\"t\":4710,\"v\":0.6},{\"t\":5080,\"v\":1},{\"t\":5090,\"v\":0},{\"t\":5100,\"v\":0},{\"t\":5110,\"v\":0.6},{\"t\":5480,\"v\":1},{\"t\":5490,\"v\":0},{\"t\":5500,\"v\":0},{\"t\":5510,\"v\":0.6},{\"t\":5880,\"v\":1},{\"t\":5890,\"v\":0},{\"t\":5900,\"v\":0},{\"t\":5910,\"v\":0.6},{\"t\":6380,\"v\":1},{\"t\":6390,\"v\":0}]},\"eAhZY4D5jNs39\":{\"transform\":{\"data\":{\"t\":{\"x\":-113.456859,\"y\":-93.548494}},\"keys\":{\"o\":[{\"t\":1600,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":1700,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":1900,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":1990,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":2000,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":2100,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":2300,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":2390,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":2400,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":2500,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":2700,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":2790,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":2800,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":2900,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":3100,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":3190,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":3200,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":3300,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":3500,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":3590,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":3600,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":3700,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":3900,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":3990,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":4000,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":4100,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":4300,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":4390,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":4400,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":4500,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":4700,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":4790,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":4800,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":4900,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":5100,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":5190,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":5200,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":5300,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":5500,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":5590,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":5600,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":5700,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":5900,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":5990,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":6000,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":6100,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":6400,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":6600,\"v\":{\"x\":113.391674,\"y\":100.830476,\"type\":\"corner\"}},{\"t\":6900,\"v\":{\"x\":113.391674,\"y\":100.830476,\"type\":\"corner\"}},{\"t\":7400,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]}],\"r\":[{\"t\":1600,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":1700,\"v\":-56.495152},{\"t\":1900,\"v\":53.92933},{\"t\":1990,\"v\":70},{\"t\":2000,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":2100,\"v\":-56.495152},{\"t\":2300,\"v\":53.92933},{\"t\":2390,\"v\":70},{\"t\":2400,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":2500,\"v\":-56.495152},{\"t\":2700,\"v\":53.92933},{\"t\":2790,\"v\":70},{\"t\":2800,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":2900,\"v\":-56.495152},{\"t\":3100,\"v\":53.92933},{\"t\":3190,\"v\":70},{\"t\":3200,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":3300,\"v\":-56.495152},{\"t\":3500,\"v\":53.92933},{\"t\":3590,\"v\":70},{\"t\":3600,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":3700,\"v\":-56.495152},{\"t\":3900,\"v\":53.92933},{\"t\":3990,\"v\":70},{\"t\":4000,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":4100,\"v\":-56.495152},{\"t\":4300,\"v\":53.92933},{\"t\":4390,\"v\":70},{\"t\":4400,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":4500,\"v\":-56.495152},{\"t\":4700,\"v\":53.92933},{\"t\":4790,\"v\":70},{\"t\":4800,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":4900,\"v\":-56.495152},{\"t\":5100,\"v\":53.92933},{\"t\":5190,\"v\":70},{\"t\":5200,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":5300,\"v\":-56.495152},{\"t\":5500,\"v\":53.92933},{\"t\":5590,\"v\":70},{\"t\":5600,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":5700,\"v\":-56.495152},{\"t\":5900,\"v\":53.92933},{\"t\":5990,\"v\":70},{\"t\":6000,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":6100,\"v\":-56.495152},{\"t\":6400,\"v\":53.92933},{\"t\":6600,\"v\":59.004278},{\"t\":6900,\"v\":59.004278},{\"t\":7400,\"v\":53.92933}],\"s\":[{\"t\":1600,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":1800,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":1990,\"v\":{\"x\":1,\"y\":1}},{\"t\":2000,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":2200,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":2390,\"v\":{\"x\":1,\"y\":1}},{\"t\":2400,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":2600,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":2790,\"v\":{\"x\":1,\"y\":1}},{\"t\":2800,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":3000,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":3190,\"v\":{\"x\":1,\"y\":1}},{\"t\":3200,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":3400,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":3590,\"v\":{\"x\":1,\"y\":1}},{\"t\":3600,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":3800,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":3990,\"v\":{\"x\":1,\"y\":1}},{\"t\":4000,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":4200,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":4390,\"v\":{\"x\":1,\"y\":1}},{\"t\":4400,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":4600,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":4790,\"v\":{\"x\":1,\"y\":1}},{\"t\":4800,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":5000,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":5190,\"v\":{\"x\":1,\"y\":1}},{\"t\":5200,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":5400,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":5590,\"v\":{\"x\":1,\"y\":1}},{\"t\":5600,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":5800,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":5990,\"v\":{\"x\":1,\"y\":1}},{\"t\":6000,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":6200,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":6400,\"v\":{\"x\":0.913217,\"y\":1}},{\"t\":6600,\"v\":{\"x\":0.957901,\"y\":1}},{\"t\":6900,\"v\":{\"x\":0.957901,\"y\":1}},{\"t\":7400,\"v\":{\"x\":0.913217,\"y\":1}}]}},\"opacity\":[{\"t\":1600,\"v\":0},{\"t\":1610,\"v\":0.6},{\"t\":1980,\"v\":1},{\"t\":1990,\"v\":0},{\"t\":2000,\"v\":0},{\"t\":2010,\"v\":0.6},{\"t\":2380,\"v\":1},{\"t\":2390,\"v\":0},{\"t\":2400,\"v\":0},{\"t\":2410,\"v\":0.6},{\"t\":2780,\"v\":1},{\"t\":2790,\"v\":0},{\"t\":2800,\"v\":0},{\"t\":2810,\"v\":0.6},{\"t\":3180,\"v\":1},{\"t\":3190,\"v\":0},{\"t\":3200,\"v\":0},{\"t\":3210,\"v\":0.6},{\"t\":3580,\"v\":1},{\"t\":3590,\"v\":0},{\"t\":3600,\"v\":0},{\"t\":3610,\"v\":0.6},{\"t\":3980,\"v\":1},{\"t\":3990,\"v\":0},{\"t\":4000,\"v\":0},{\"t\":4010,\"v\":0.6},{\"t\":4380,\"v\":1},{\"t\":4390,\"v\":0},{\"t\":4400,\"v\":0},{\"t\":4410,\"v\":0.6},{\"t\":4780,\"v\":1},{\"t\":4790,\"v\":0},{\"t\":4800,\"v\":0},{\"t\":4810,\"v\":0.6},{\"t\":5180,\"v\":1},{\"t\":5190,\"v\":0},{\"t\":5200,\"v\":0},{\"t\":5210,\"v\":0.6},{\"t\":5580,\"v\":1},{\"t\":5590,\"v\":0},{\"t\":5600,\"v\":0},{\"t\":5610,\"v\":0.6},{\"t\":5980,\"v\":1},{\"t\":5990,\"v\":0},{\"t\":6000,\"v\":0},{\"t\":6010,\"v\":0.6},{\"t\":6400,\"v\":0.906494}]},\"eAhZY4D5jNs40\":{\"transform\":{\"data\":{\"t\":{\"x\":-113.456859,\"y\":-93.548494}},\"keys\":{\"o\":[{\"t\":1700,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":1800,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":2000,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":2090,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":2100,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":2200,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":2400,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":2490,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":2500,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":2600,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":2800,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":2890,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":2900,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":3000,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":3200,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":3290,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":3300,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":3400,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":3600,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":3690,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":3700,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":3800,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":4000,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":4090,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":4100,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":4200,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":4400,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":4490,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":4500,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":4600,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":4800,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":4890,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":4900,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":5000,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":5200,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":5290,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":5300,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":5400,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":5600,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":5690,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":5700,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":5800,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":6000,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":6090,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":6100,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":6200,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":6400,\"v\":{\"x\":114,\"y\":93.573387,\"type\":\"corner\"}},{\"t\":6600,\"v\":{\"x\":114,\"y\":95.438553,\"type\":\"corner\"}},{\"t\":6900,\"v\":{\"x\":114,\"y\":95.438553,\"type\":\"corner\"}},{\"t\":7400,\"v\":{\"x\":114,\"y\":93.573387,\"type\":\"corner\"}}],\"r\":[{\"t\":1700,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":1800,\"v\":-56.495152},{\"t\":2000,\"v\":53.92933},{\"t\":2090,\"v\":70},{\"t\":2100,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":2200,\"v\":-56.495152},{\"t\":2400,\"v\":53.92933},{\"t\":2490,\"v\":70},{\"t\":2500,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":2600,\"v\":-56.495152},{\"t\":2800,\"v\":53.92933},{\"t\":2890,\"v\":70},{\"t\":2900,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":3000,\"v\":-56.495152},{\"t\":3200,\"v\":53.92933},{\"t\":3290,\"v\":70},{\"t\":3300,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":3400,\"v\":-56.495152},{\"t\":3600,\"v\":53.92933},{\"t\":3690,\"v\":70},{\"t\":3700,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":3800,\"v\":-56.495152},{\"t\":4000,\"v\":53.92933},{\"t\":4090,\"v\":70},{\"t\":4100,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":4200,\"v\":-56.495152},{\"t\":4400,\"v\":53.92933},{\"t\":4490,\"v\":70},{\"t\":4500,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":4600,\"v\":-56.495152},{\"t\":4800,\"v\":53.92933},{\"t\":4890,\"v\":70},{\"t\":4900,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":5000,\"v\":-56.495152},{\"t\":5200,\"v\":53.92933},{\"t\":5290,\"v\":70},{\"t\":5300,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":5400,\"v\":-56.495152},{\"t\":5600,\"v\":53.92933},{\"t\":5690,\"v\":70},{\"t\":5700,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":5800,\"v\":-56.495152},{\"t\":6000,\"v\":53.92933},{\"t\":6090,\"v\":70},{\"t\":6100,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":6200,\"v\":-56.495152},{\"t\":6400,\"v\":-1.282911},{\"t\":6600,\"v\":15.280761},{\"t\":6900,\"v\":15.280761},{\"t\":7400,\"v\":-1.282911}],\"s\":[{\"t\":1700,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":1900,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":2090,\"v\":{\"x\":1,\"y\":1}},{\"t\":2100,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":2300,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":2490,\"v\":{\"x\":1,\"y\":1}},{\"t\":2500,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":2700,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":2890,\"v\":{\"x\":1,\"y\":1}},{\"t\":2900,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":3100,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":3290,\"v\":{\"x\":1,\"y\":1}},{\"t\":3300,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":3500,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":3690,\"v\":{\"x\":1,\"y\":1}},{\"t\":3700,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":3900,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":4090,\"v\":{\"x\":1,\"y\":1}},{\"t\":4100,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":4300,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":4490,\"v\":{\"x\":1,\"y\":1}},{\"t\":4500,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":4700,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":4890,\"v\":{\"x\":1,\"y\":1}},{\"t\":4900,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":5100,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":5290,\"v\":{\"x\":1,\"y\":1}},{\"t\":5300,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":5500,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":5690,\"v\":{\"x\":1,\"y\":1}},{\"t\":5700,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":5900,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":6090,\"v\":{\"x\":1,\"y\":1}},{\"t\":6100,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":6400,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":6600,\"v\":{\"x\":0.714801,\"y\":1}},{\"t\":6900,\"v\":{\"x\":0.714801,\"y\":1}},{\"t\":7400,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]}]}},\"opacity\":[{\"t\":1700,\"v\":0},{\"t\":1710,\"v\":0.6},{\"t\":2080,\"v\":1},{\"t\":2090,\"v\":0},{\"t\":2100,\"v\":0},{\"t\":2110,\"v\":0.6},{\"t\":2480,\"v\":1},{\"t\":2490,\"v\":0},{\"t\":2500,\"v\":0},{\"t\":2510,\"v\":0.6},{\"t\":2880,\"v\":1},{\"t\":2890,\"v\":0},{\"t\":2900,\"v\":0},{\"t\":2910,\"v\":0.6},{\"t\":3280,\"v\":1},{\"t\":3290,\"v\":0},{\"t\":3300,\"v\":0},{\"t\":3310,\"v\":0.6},{\"t\":3680,\"v\":1},{\"t\":3690,\"v\":0},{\"t\":3700,\"v\":0},{\"t\":3710,\"v\":0.6},{\"t\":4080,\"v\":1},{\"t\":4090,\"v\":0},{\"t\":4100,\"v\":0},{\"t\":4110,\"v\":0.6},{\"t\":4480,\"v\":1},{\"t\":4490,\"v\":0},{\"t\":4500,\"v\":0},{\"t\":4510,\"v\":0.6},{\"t\":4880,\"v\":1},{\"t\":4890,\"v\":0},{\"t\":4900,\"v\":0},{\"t\":4910,\"v\":0.6},{\"t\":5280,\"v\":1},{\"t\":5290,\"v\":0},{\"t\":5300,\"v\":0},{\"t\":5310,\"v\":0.6},{\"t\":5680,\"v\":1},{\"t\":5690,\"v\":0},{\"t\":5700,\"v\":0},{\"t\":5710,\"v\":0.6},{\"t\":6080,\"v\":1},{\"t\":6090,\"v\":0},{\"t\":6100,\"v\":0},{\"t\":6110,\"v\":0.6},{\"t\":6400,\"v\":0.802597}]},\"eAhZY4D5jNs41\":{\"transform\":{\"data\":{\"t\":{\"x\":-113.456859,\"y\":-93.548494}},\"keys\":{\"o\":[{\"t\":1800,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":1900,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":2100,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":2190,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":2200,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":2300,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":2500,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":2590,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":2600,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":2700,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":2900,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":2990,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":3000,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":3100,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":3300,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":3390,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":3400,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":3500,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":3700,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":3790,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":3800,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":3900,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":4100,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":4190,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":4200,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":4300,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":4500,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":4590,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":4600,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":4700,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":4900,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":4990,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":5000,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":5100,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":5300,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":5390,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":5400,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":5500,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":5700,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":5790,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":5800,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":5900,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":6100,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":6190,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":6200,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":6400,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":6600,\"v\":{\"x\":114,\"y\":89.221332,\"type\":\"corner\"}},{\"t\":6900,\"v\":{\"x\":114,\"y\":89.221332,\"type\":\"corner\"}},{\"t\":7400,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}}],\"r\":[{\"t\":1800,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":1900,\"v\":-56.495152},{\"t\":2100,\"v\":53.92933},{\"t\":2190,\"v\":70},{\"t\":2200,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":2300,\"v\":-56.495152},{\"t\":2500,\"v\":53.92933},{\"t\":2590,\"v\":70},{\"t\":2600,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":2700,\"v\":-56.495152},{\"t\":2900,\"v\":53.92933},{\"t\":2990,\"v\":70},{\"t\":3000,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":3100,\"v\":-56.495152},{\"t\":3300,\"v\":53.92933},{\"t\":3390,\"v\":70},{\"t\":3400,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":3500,\"v\":-56.495152},{\"t\":3700,\"v\":53.92933},{\"t\":3790,\"v\":70},{\"t\":3800,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":3900,\"v\":-56.495152},{\"t\":4100,\"v\":53.92933},{\"t\":4190,\"v\":70},{\"t\":4200,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":4300,\"v\":-56.495152},{\"t\":4500,\"v\":53.92933},{\"t\":4590,\"v\":70},{\"t\":4600,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":4700,\"v\":-56.495152},{\"t\":4900,\"v\":53.92933},{\"t\":4990,\"v\":70},{\"t\":5000,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":5100,\"v\":-56.495152},{\"t\":5300,\"v\":53.92933},{\"t\":5390,\"v\":70},{\"t\":5400,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":5500,\"v\":-56.495152},{\"t\":5700,\"v\":53.92933},{\"t\":5790,\"v\":70},{\"t\":5800,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":5900,\"v\":-56.495152},{\"t\":6100,\"v\":53.92933},{\"t\":6190,\"v\":70},{\"t\":6200,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":6400,\"v\":-56.495152},{\"t\":6600,\"v\":-39.931479},{\"t\":6900,\"v\":-39.931479},{\"t\":7400,\"v\":-56.495152}],\"s\":[{\"t\":1800,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":2000,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":2190,\"v\":{\"x\":1,\"y\":1}},{\"t\":2200,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":2400,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":2590,\"v\":{\"x\":1,\"y\":1}},{\"t\":2600,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":2800,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":2990,\"v\":{\"x\":1,\"y\":1}},{\"t\":3000,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":3200,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":3390,\"v\":{\"x\":1,\"y\":1}},{\"t\":3400,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":3600,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":3790,\"v\":{\"x\":1,\"y\":1}},{\"t\":3800,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":4000,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":4190,\"v\":{\"x\":1,\"y\":1}},{\"t\":4200,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":4400,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":4590,\"v\":{\"x\":1,\"y\":1}},{\"t\":4600,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":4800,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":4990,\"v\":{\"x\":1,\"y\":1}},{\"t\":5000,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":5200,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":5390,\"v\":{\"x\":1,\"y\":1}},{\"t\":5400,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":5600,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":5790,\"v\":{\"x\":1,\"y\":1}},{\"t\":5800,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":6000,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":6190,\"v\":{\"x\":1,\"y\":1}},{\"t\":6200,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":6400,\"v\":{\"x\":0.897604,\"y\":1}},{\"t\":6600,\"v\":{\"x\":0.822907,\"y\":1}},{\"t\":6900,\"v\":{\"x\":0.822907,\"y\":1}},{\"t\":7400,\"v\":{\"x\":0.897604,\"y\":1}}]}},\"opacity\":[{\"t\":1800,\"v\":0},{\"t\":1810,\"v\":0.6},{\"t\":2180,\"v\":1},{\"t\":2190,\"v\":0},{\"t\":2200,\"v\":0},{\"t\":2210,\"v\":0.6},{\"t\":2580,\"v\":1},{\"t\":2590,\"v\":0},{\"t\":2600,\"v\":0},{\"t\":2610,\"v\":0.6},{\"t\":2980,\"v\":1},{\"t\":2990,\"v\":0},{\"t\":3000,\"v\":0},{\"t\":3010,\"v\":0.6},{\"t\":3380,\"v\":1},{\"t\":3390,\"v\":0},{\"t\":3400,\"v\":0},{\"t\":3410,\"v\":0.6},{\"t\":3780,\"v\":1},{\"t\":3790,\"v\":0},{\"t\":3800,\"v\":0},{\"t\":3810,\"v\":0.6},{\"t\":4180,\"v\":1},{\"t\":4190,\"v\":0},{\"t\":4200,\"v\":0},{\"t\":4210,\"v\":0.6},{\"t\":4580,\"v\":1},{\"t\":4590,\"v\":0},{\"t\":4600,\"v\":0},{\"t\":4610,\"v\":0.6},{\"t\":4980,\"v\":1},{\"t\":4990,\"v\":0},{\"t\":5000,\"v\":0},{\"t\":5010,\"v\":0.6},{\"t\":5380,\"v\":1},{\"t\":5390,\"v\":0},{\"t\":5400,\"v\":0},{\"t\":5410,\"v\":0.6},{\"t\":5780,\"v\":1},{\"t\":5790,\"v\":0},{\"t\":5800,\"v\":0},{\"t\":5810,\"v\":0.6},{\"t\":6180,\"v\":1},{\"t\":6190,\"v\":0},{\"t\":6200,\"v\":0},{\"t\":6210,\"v\":0.6},{\"t\":6400,\"v\":0.698701}]},\"eAhZY4D5jNs43\":{\"transform\":{\"data\":{\"t\":{\"x\":-132.47,\"y\":-93.723625}},\"keys\":{\"o\":[{\"t\":0,\"v\":{\"x\":132.47,\"y\":93.723625,\"type\":\"corner\"},\"e\":[0.645,0.045,0.345,1.34]},{\"t\":200,\"v\":{\"x\":124.309999,\"y\":100.163628,\"type\":\"corner\"}},{\"t\":8500,\"v\":{\"x\":124.309999,\"y\":100.163628,\"type\":\"corner\"}},{\"t\":9000,\"v\":{\"x\":132.47,\"y\":93.723625,\"type\":\"corner\"},\"e\":[0.645,0.045,0.345,1.34]}]}}},\"eAhZY4D5jNs49\":{\"transform\":{\"data\":{\"t\":{\"x\":-113.456859,\"y\":-93.548494}},\"keys\":{\"o\":[{\"t\":390,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0.42,0,0.215,1]},{\"t\":890,\"v\":{\"x\":114,\"y\":97.61458,\"type\":\"corner\"},\"e\":[0.84,0.005,1,1]},{\"t\":1400,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":1590,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}}],\"r\":[{\"t\":390,\"v\":53.92933,\"e\":[0.42,0,0.215,1]},{\"t\":890,\"v\":34.605046,\"e\":[0.84,0.005,1,1]},{\"t\":1400,\"v\":53.92933},{\"t\":1590,\"v\":70}],\"s\":[{\"t\":390,\"v\":{\"x\":0.908528,\"y\":1},\"e\":[0.42,0,0.215,1]},{\"t\":890,\"v\":{\"x\":0.877199,\"y\":1},\"e\":[0.84,0.005,1,1]},{\"t\":1400,\"v\":{\"x\":0.908528,\"y\":1}},{\"t\":1590,\"v\":{\"x\":1,\"y\":1}}]}},\"opacity\":[{\"t\":1400,\"v\":0.902564},{\"t\":1580,\"v\":1},{\"t\":1590,\"v\":0}]},\"eAhZY4D5jNs50\":{\"transform\":{\"data\":{\"t\":{\"x\":-113.456859,\"y\":-93.548494}},\"keys\":{\"o\":[{\"t\":390,\"v\":{\"x\":114,\"y\":93.573387,\"type\":\"corner\"},\"e\":[0.42,0,0.215,1]},{\"t\":890,\"v\":{\"x\":114,\"y\":91.39736,\"type\":\"corner\"},\"e\":[0.84,0.005,1,1]},{\"t\":1400,\"v\":{\"x\":114,\"y\":93.573387,\"type\":\"corner\"}},{\"t\":1600,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":1690,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}}],\"r\":[{\"t\":390,\"v\":-1.282911,\"e\":[0.42,0,0.215,1]},{\"t\":890,\"v\":-20.607195,\"e\":[0.84,0.005,1,1]},{\"t\":1400,\"v\":-1.282911},{\"t\":1600,\"v\":53.92933},{\"t\":1690,\"v\":70}],\"s\":[{\"t\":390,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.42,0,0.215,1]},{\"t\":890,\"v\":{\"x\":0.71114,\"y\":1},\"e\":[0.84,0.005,1,1]},{\"t\":1400,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":1690,\"v\":{\"x\":1,\"y\":1}}]}},\"opacity\":[{\"t\":1400,\"v\":0.8},{\"t\":1680,\"v\":1},{\"t\":1690,\"v\":0}]},\"eAhZY4D5jNs51\":{\"transform\":{\"data\":{\"t\":{\"x\":-113.456859,\"y\":-93.548494}},\"keys\":{\"o\":[{\"t\":390,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"},\"e\":[0.42,0,0.215,1]},{\"t\":890,\"v\":{\"x\":113.39185,\"y\":86.344662,\"type\":\"corner\"},\"e\":[0.84,0.005,1,1]},{\"t\":1400,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":1700,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":1790,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}}],\"r\":[{\"t\":390,\"v\":-56.495152,\"e\":[0.42,0,0.215,1]},{\"t\":890,\"v\":-58.732873,\"e\":[0.84,0.005,1,1]},{\"t\":1400,\"v\":-56.495152},{\"t\":1700,\"v\":53.92933},{\"t\":1790,\"v\":70}],\"s\":[{\"t\":390,\"v\":{\"x\":0.897604,\"y\":1},\"e\":[0.42,0,0.215,1]},{\"t\":890,\"v\":{\"x\":0.954666,\"y\":1},\"e\":[0.84,0.005,1,1]},{\"t\":1400,\"v\":{\"x\":0.897604,\"y\":1}},{\"t\":1600,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":1790,\"v\":{\"x\":1,\"y\":1}}]}},\"opacity\":[{\"t\":1400,\"v\":0.697436},{\"t\":1780,\"v\":1},{\"t\":1790,\"v\":0}]},\"eAhZY4D5jNs52\":{\"transform\":{\"data\":{\"t\":{\"x\":-113.456859,\"y\":-93.548494}},\"keys\":{\"o\":[{\"t\":1400,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":1600,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":1800,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":1890,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":1900,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":2000,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":2200,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":2290,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":2300,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":2400,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":2600,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":2690,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":2700,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":2800,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":3000,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":3090,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":3100,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":3200,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":3400,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":3490,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":3500,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":3600,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":3800,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":3890,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":3900,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":4000,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":4200,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":4290,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":4300,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":4400,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":4600,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":4690,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":4700,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":4800,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":5000,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":5090,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":5100,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":5200,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":5400,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":5490,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":5500,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":5600,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":5800,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":5890,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":5900,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":6000,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":6200,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":6390,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}}],\"r\":[{\"t\":1400,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":1600,\"v\":-56.495152},{\"t\":1800,\"v\":53.92933},{\"t\":1890,\"v\":70},{\"t\":1900,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":2000,\"v\":-56.495152},{\"t\":2200,\"v\":53.92933},{\"t\":2290,\"v\":70},{\"t\":2300,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":2400,\"v\":-56.495152},{\"t\":2600,\"v\":53.92933},{\"t\":2690,\"v\":70},{\"t\":2700,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":2800,\"v\":-56.495152},{\"t\":3000,\"v\":53.92933},{\"t\":3090,\"v\":70},{\"t\":3100,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":3200,\"v\":-56.495152},{\"t\":3400,\"v\":53.92933},{\"t\":3490,\"v\":70},{\"t\":3500,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":3600,\"v\":-56.495152},{\"t\":3800,\"v\":53.92933},{\"t\":3890,\"v\":70},{\"t\":3900,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":4000,\"v\":-56.495152},{\"t\":4200,\"v\":53.92933},{\"t\":4290,\"v\":70},{\"t\":4300,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":4400,\"v\":-56.495152},{\"t\":4600,\"v\":53.92933},{\"t\":4690,\"v\":70},{\"t\":4700,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":4800,\"v\":-56.495152},{\"t\":5000,\"v\":53.92933},{\"t\":5090,\"v\":70},{\"t\":5100,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":5200,\"v\":-56.495152},{\"t\":5400,\"v\":53.92933},{\"t\":5490,\"v\":70},{\"t\":5500,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":5600,\"v\":-56.495152},{\"t\":5800,\"v\":53.92933},{\"t\":5890,\"v\":70},{\"t\":5900,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":6000,\"v\":-56.495152},{\"t\":6200,\"v\":53.92933},{\"t\":6390,\"v\":70}],\"s\":[{\"t\":1400,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":1700,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":1890,\"v\":{\"x\":1,\"y\":1}},{\"t\":1900,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":2100,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":2290,\"v\":{\"x\":1,\"y\":1}},{\"t\":2300,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":2500,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":2690,\"v\":{\"x\":1,\"y\":1}},{\"t\":2700,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":2900,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":3090,\"v\":{\"x\":1,\"y\":1}},{\"t\":3100,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":3300,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":3490,\"v\":{\"x\":1,\"y\":1}},{\"t\":3500,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":3700,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":3890,\"v\":{\"x\":1,\"y\":1}},{\"t\":3900,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":4100,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":4290,\"v\":{\"x\":1,\"y\":1}},{\"t\":4300,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":4500,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":4690,\"v\":{\"x\":1,\"y\":1}},{\"t\":4700,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":4900,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":5090,\"v\":{\"x\":1,\"y\":1}},{\"t\":5100,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":5300,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":5490,\"v\":{\"x\":1,\"y\":1}},{\"t\":5500,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":5700,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":5890,\"v\":{\"x\":1,\"y\":1}},{\"t\":5900,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":6100,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":6390,\"v\":{\"x\":1,\"y\":1}}]}},\"opacity\":[{\"t\":1400,\"v\":0},{\"t\":1410,\"v\":0.6},{\"t\":1880,\"v\":1},{\"t\":1890,\"v\":0},{\"t\":1900,\"v\":0},{\"t\":1910,\"v\":0.6},{\"t\":2280,\"v\":1},{\"t\":2290,\"v\":0},{\"t\":2300,\"v\":0},{\"t\":2310,\"v\":0.6},{\"t\":2680,\"v\":1},{\"t\":2690,\"v\":0},{\"t\":2700,\"v\":0},{\"t\":2710,\"v\":0.6},{\"t\":3080,\"v\":1},{\"t\":3090,\"v\":0},{\"t\":3100,\"v\":0},{\"t\":3110,\"v\":0.6},{\"t\":3480,\"v\":1},{\"t\":3490,\"v\":0},{\"t\":3500,\"v\":0},{\"t\":3510,\"v\":0.6},{\"t\":3880,\"v\":1},{\"t\":3890,\"v\":0},{\"t\":3900,\"v\":0},{\"t\":3910,\"v\":0.6},{\"t\":4280,\"v\":1},{\"t\":4290,\"v\":0},{\"t\":4300,\"v\":0},{\"t\":4310,\"v\":0.6},{\"t\":4680,\"v\":1},{\"t\":4690,\"v\":0},{\"t\":4700,\"v\":0},{\"t\":4710,\"v\":0.6},{\"t\":5080,\"v\":1},{\"t\":5090,\"v\":0},{\"t\":5100,\"v\":0},{\"t\":5110,\"v\":0.6},{\"t\":5480,\"v\":1},{\"t\":5490,\"v\":0},{\"t\":5500,\"v\":0},{\"t\":5510,\"v\":0.6},{\"t\":5880,\"v\":1},{\"t\":5890,\"v\":0},{\"t\":5900,\"v\":0},{\"t\":5910,\"v\":0.6},{\"t\":6380,\"v\":1},{\"t\":6390,\"v\":0}]},\"eAhZY4D5jNs53\":{\"transform\":{\"data\":{\"t\":{\"x\":-113.456859,\"y\":-93.548494}},\"keys\":{\"o\":[{\"t\":1600,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":1700,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":1900,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":1990,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":2000,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":2100,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":2300,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":2390,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":2400,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":2500,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":2700,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":2790,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":2800,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":2900,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":3100,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":3190,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":3200,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":3300,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":3500,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":3590,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":3600,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":3700,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":3900,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":3990,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":4000,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":4100,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":4300,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":4390,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":4400,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":4500,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":4700,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":4790,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":4800,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":4900,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":5100,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":5190,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":5200,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":5300,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":5500,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":5590,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":5600,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":5700,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":5900,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":5990,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":6000,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":6100,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":6400,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":6600,\"v\":{\"x\":113.391674,\"y\":100.830476,\"type\":\"corner\"}},{\"t\":6900,\"v\":{\"x\":113.391674,\"y\":100.830476,\"type\":\"corner\"}},{\"t\":7400,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]}],\"r\":[{\"t\":1600,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":1700,\"v\":-56.495152},{\"t\":1900,\"v\":53.92933},{\"t\":1990,\"v\":70},{\"t\":2000,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":2100,\"v\":-56.495152},{\"t\":2300,\"v\":53.92933},{\"t\":2390,\"v\":70},{\"t\":2400,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":2500,\"v\":-56.495152},{\"t\":2700,\"v\":53.92933},{\"t\":2790,\"v\":70},{\"t\":2800,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":2900,\"v\":-56.495152},{\"t\":3100,\"v\":53.92933},{\"t\":3190,\"v\":70},{\"t\":3200,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":3300,\"v\":-56.495152},{\"t\":3500,\"v\":53.92933},{\"t\":3590,\"v\":70},{\"t\":3600,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":3700,\"v\":-56.495152},{\"t\":3900,\"v\":53.92933},{\"t\":3990,\"v\":70},{\"t\":4000,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":4100,\"v\":-56.495152},{\"t\":4300,\"v\":53.92933},{\"t\":4390,\"v\":70},{\"t\":4400,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":4500,\"v\":-56.495152},{\"t\":4700,\"v\":53.92933},{\"t\":4790,\"v\":70},{\"t\":4800,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":4900,\"v\":-56.495152},{\"t\":5100,\"v\":53.92933},{\"t\":5190,\"v\":70},{\"t\":5200,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":5300,\"v\":-56.495152},{\"t\":5500,\"v\":53.92933},{\"t\":5590,\"v\":70},{\"t\":5600,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":5700,\"v\":-56.495152},{\"t\":5900,\"v\":53.92933},{\"t\":5990,\"v\":70},{\"t\":6000,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":6100,\"v\":-56.495152},{\"t\":6400,\"v\":53.92933},{\"t\":6600,\"v\":59.004278},{\"t\":6900,\"v\":59.004278},{\"t\":7400,\"v\":53.92933}],\"s\":[{\"t\":1600,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":1800,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":1990,\"v\":{\"x\":1,\"y\":1}},{\"t\":2000,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":2200,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":2390,\"v\":{\"x\":1,\"y\":1}},{\"t\":2400,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":2600,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":2790,\"v\":{\"x\":1,\"y\":1}},{\"t\":2800,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":3000,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":3190,\"v\":{\"x\":1,\"y\":1}},{\"t\":3200,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":3400,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":3590,\"v\":{\"x\":1,\"y\":1}},{\"t\":3600,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":3800,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":3990,\"v\":{\"x\":1,\"y\":1}},{\"t\":4000,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":4200,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":4390,\"v\":{\"x\":1,\"y\":1}},{\"t\":4400,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":4600,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":4790,\"v\":{\"x\":1,\"y\":1}},{\"t\":4800,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":5000,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":5190,\"v\":{\"x\":1,\"y\":1}},{\"t\":5200,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":5400,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":5590,\"v\":{\"x\":1,\"y\":1}},{\"t\":5600,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":5800,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":5990,\"v\":{\"x\":1,\"y\":1}},{\"t\":6000,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":6200,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":6400,\"v\":{\"x\":0.913217,\"y\":1}},{\"t\":6600,\"v\":{\"x\":0.957901,\"y\":1}},{\"t\":6900,\"v\":{\"x\":0.957901,\"y\":1}},{\"t\":7400,\"v\":{\"x\":0.913217,\"y\":1}}]}},\"opacity\":[{\"t\":1600,\"v\":0},{\"t\":1610,\"v\":0.6},{\"t\":1980,\"v\":1},{\"t\":1990,\"v\":0},{\"t\":2000,\"v\":0},{\"t\":2010,\"v\":0.6},{\"t\":2380,\"v\":1},{\"t\":2390,\"v\":0},{\"t\":2400,\"v\":0},{\"t\":2410,\"v\":0.6},{\"t\":2780,\"v\":1},{\"t\":2790,\"v\":0},{\"t\":2800,\"v\":0},{\"t\":2810,\"v\":0.6},{\"t\":3180,\"v\":1},{\"t\":3190,\"v\":0},{\"t\":3200,\"v\":0},{\"t\":3210,\"v\":0.6},{\"t\":3580,\"v\":1},{\"t\":3590,\"v\":0},{\"t\":3600,\"v\":0},{\"t\":3610,\"v\":0.6},{\"t\":3980,\"v\":1},{\"t\":3990,\"v\":0},{\"t\":4000,\"v\":0},{\"t\":4010,\"v\":0.6},{\"t\":4380,\"v\":1},{\"t\":4390,\"v\":0},{\"t\":4400,\"v\":0},{\"t\":4410,\"v\":0.6},{\"t\":4780,\"v\":1},{\"t\":4790,\"v\":0},{\"t\":4800,\"v\":0},{\"t\":4810,\"v\":0.6},{\"t\":5180,\"v\":1},{\"t\":5190,\"v\":0},{\"t\":5200,\"v\":0},{\"t\":5210,\"v\":0.6},{\"t\":5580,\"v\":1},{\"t\":5590,\"v\":0},{\"t\":5600,\"v\":0},{\"t\":5610,\"v\":0.6},{\"t\":5980,\"v\":1},{\"t\":5990,\"v\":0},{\"t\":6000,\"v\":0},{\"t\":6010,\"v\":0.6},{\"t\":6400,\"v\":0.906494}]},\"eAhZY4D5jNs54\":{\"transform\":{\"data\":{\"t\":{\"x\":-113.456859,\"y\":-93.548494}},\"keys\":{\"o\":[{\"t\":1700,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":1800,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":2000,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":2090,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":2100,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":2200,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":2400,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":2490,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":2500,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":2600,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":2800,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":2890,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":2900,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":3000,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":3200,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":3290,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":3300,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":3400,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":3600,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":3690,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":3700,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":3800,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":4000,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":4090,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":4100,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":4200,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":4400,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":4490,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":4500,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":4600,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":4800,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":4890,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":4900,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":5000,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":5200,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":5290,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":5300,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":5400,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":5600,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":5690,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":5700,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":5800,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":6000,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":6090,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":6100,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":6200,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":6400,\"v\":{\"x\":114,\"y\":93.573387,\"type\":\"corner\"}},{\"t\":6600,\"v\":{\"x\":114,\"y\":95.438553,\"type\":\"corner\"}},{\"t\":6900,\"v\":{\"x\":114,\"y\":95.438553,\"type\":\"corner\"}},{\"t\":7400,\"v\":{\"x\":114,\"y\":93.573387,\"type\":\"corner\"}}],\"r\":[{\"t\":1700,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":1800,\"v\":-56.495152},{\"t\":2000,\"v\":53.92933},{\"t\":2090,\"v\":70},{\"t\":2100,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":2200,\"v\":-56.495152},{\"t\":2400,\"v\":53.92933},{\"t\":2490,\"v\":70},{\"t\":2500,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":2600,\"v\":-56.495152},{\"t\":2800,\"v\":53.92933},{\"t\":2890,\"v\":70},{\"t\":2900,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":3000,\"v\":-56.495152},{\"t\":3200,\"v\":53.92933},{\"t\":3290,\"v\":70},{\"t\":3300,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":3400,\"v\":-56.495152},{\"t\":3600,\"v\":53.92933},{\"t\":3690,\"v\":70},{\"t\":3700,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":3800,\"v\":-56.495152},{\"t\":4000,\"v\":53.92933},{\"t\":4090,\"v\":70},{\"t\":4100,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":4200,\"v\":-56.495152},{\"t\":4400,\"v\":53.92933},{\"t\":4490,\"v\":70},{\"t\":4500,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":4600,\"v\":-56.495152},{\"t\":4800,\"v\":53.92933},{\"t\":4890,\"v\":70},{\"t\":4900,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":5000,\"v\":-56.495152},{\"t\":5200,\"v\":53.92933},{\"t\":5290,\"v\":70},{\"t\":5300,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":5400,\"v\":-56.495152},{\"t\":5600,\"v\":53.92933},{\"t\":5690,\"v\":70},{\"t\":5700,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":5800,\"v\":-56.495152},{\"t\":6000,\"v\":53.92933},{\"t\":6090,\"v\":70},{\"t\":6100,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":6200,\"v\":-56.495152},{\"t\":6400,\"v\":-1.282911},{\"t\":6600,\"v\":15.280761},{\"t\":6900,\"v\":15.280761},{\"t\":7400,\"v\":-1.282911}],\"s\":[{\"t\":1700,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":1900,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":2090,\"v\":{\"x\":1,\"y\":1}},{\"t\":2100,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":2300,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":2490,\"v\":{\"x\":1,\"y\":1}},{\"t\":2500,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":2700,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":2890,\"v\":{\"x\":1,\"y\":1}},{\"t\":2900,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":3100,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":3290,\"v\":{\"x\":1,\"y\":1}},{\"t\":3300,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":3500,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":3690,\"v\":{\"x\":1,\"y\":1}},{\"t\":3700,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":3900,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":4090,\"v\":{\"x\":1,\"y\":1}},{\"t\":4100,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":4300,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":4490,\"v\":{\"x\":1,\"y\":1}},{\"t\":4500,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":4700,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":4890,\"v\":{\"x\":1,\"y\":1}},{\"t\":4900,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":5100,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":5290,\"v\":{\"x\":1,\"y\":1}},{\"t\":5300,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":5500,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":5690,\"v\":{\"x\":1,\"y\":1}},{\"t\":5700,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":5900,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":6090,\"v\":{\"x\":1,\"y\":1}},{\"t\":6100,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":6400,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":6600,\"v\":{\"x\":0.714801,\"y\":1}},{\"t\":6900,\"v\":{\"x\":0.714801,\"y\":1}},{\"t\":7400,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]}]}},\"opacity\":[{\"t\":1700,\"v\":0},{\"t\":1710,\"v\":0.6},{\"t\":2080,\"v\":1},{\"t\":2090,\"v\":0},{\"t\":2100,\"v\":0},{\"t\":2110,\"v\":0.6},{\"t\":2480,\"v\":1},{\"t\":2490,\"v\":0},{\"t\":2500,\"v\":0},{\"t\":2510,\"v\":0.6},{\"t\":2880,\"v\":1},{\"t\":2890,\"v\":0},{\"t\":2900,\"v\":0},{\"t\":2910,\"v\":0.6},{\"t\":3280,\"v\":1},{\"t\":3290,\"v\":0},{\"t\":3300,\"v\":0},{\"t\":3310,\"v\":0.6},{\"t\":3680,\"v\":1},{\"t\":3690,\"v\":0},{\"t\":3700,\"v\":0},{\"t\":3710,\"v\":0.6},{\"t\":4080,\"v\":1},{\"t\":4090,\"v\":0},{\"t\":4100,\"v\":0},{\"t\":4110,\"v\":0.6},{\"t\":4480,\"v\":1},{\"t\":4490,\"v\":0},{\"t\":4500,\"v\":0},{\"t\":4510,\"v\":0.6},{\"t\":4880,\"v\":1},{\"t\":4890,\"v\":0},{\"t\":4900,\"v\":0},{\"t\":4910,\"v\":0.6},{\"t\":5280,\"v\":1},{\"t\":5290,\"v\":0},{\"t\":5300,\"v\":0},{\"t\":5310,\"v\":0.6},{\"t\":5680,\"v\":1},{\"t\":5690,\"v\":0},{\"t\":5700,\"v\":0},{\"t\":5710,\"v\":0.6},{\"t\":6080,\"v\":1},{\"t\":6090,\"v\":0},{\"t\":6100,\"v\":0},{\"t\":6110,\"v\":0.6},{\"t\":6400,\"v\":0.802597}]},\"eAhZY4D5jNs55\":{\"transform\":{\"data\":{\"t\":{\"x\":-113.456859,\"y\":-93.548494}},\"keys\":{\"o\":[{\"t\":1800,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":1900,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":2100,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":2190,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":2200,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":2300,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":2500,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":2590,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":2600,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":2700,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":2900,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":2990,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":3000,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":3100,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":3300,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":3390,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":3400,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":3500,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":3700,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":3790,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":3800,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":3900,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":4100,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":4190,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":4200,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":4300,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":4500,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":4590,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":4600,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":4700,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":4900,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":4990,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":5000,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":5100,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":5300,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":5390,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":5400,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":5500,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":5700,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":5790,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":5800,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":5900,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":6100,\"v\":{\"x\":114,\"y\":99.790608,\"type\":\"corner\"},\"e\":[0,0,0.265,0.95]},{\"t\":6190,\"v\":{\"x\":113,\"y\":101.5,\"type\":\"corner\"}},{\"t\":6200,\"v\":{\"x\":112.995343,\"y\":85.685173,\"type\":\"corner\"},\"e\":[0.645,0.045,1,1]},{\"t\":6400,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}},{\"t\":6600,\"v\":{\"x\":114,\"y\":89.221332,\"type\":\"corner\"}},{\"t\":6900,\"v\":{\"x\":114,\"y\":89.221332,\"type\":\"corner\"}},{\"t\":7400,\"v\":{\"x\":114,\"y\":87.356166,\"type\":\"corner\"}}],\"r\":[{\"t\":1800,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":1900,\"v\":-56.495152},{\"t\":2100,\"v\":53.92933},{\"t\":2190,\"v\":70},{\"t\":2200,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":2300,\"v\":-56.495152},{\"t\":2500,\"v\":53.92933},{\"t\":2590,\"v\":70},{\"t\":2600,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":2700,\"v\":-56.495152},{\"t\":2900,\"v\":53.92933},{\"t\":2990,\"v\":70},{\"t\":3000,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":3100,\"v\":-56.495152},{\"t\":3300,\"v\":53.92933},{\"t\":3390,\"v\":70},{\"t\":3400,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":3500,\"v\":-56.495152},{\"t\":3700,\"v\":53.92933},{\"t\":3790,\"v\":70},{\"t\":3800,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":3900,\"v\":-56.495152},{\"t\":4100,\"v\":53.92933},{\"t\":4190,\"v\":70},{\"t\":4200,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":4300,\"v\":-56.495152},{\"t\":4500,\"v\":53.92933},{\"t\":4590,\"v\":70},{\"t\":4600,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":4700,\"v\":-56.495152},{\"t\":4900,\"v\":53.92933},{\"t\":4990,\"v\":70},{\"t\":5000,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":5100,\"v\":-56.495152},{\"t\":5300,\"v\":53.92933},{\"t\":5390,\"v\":70},{\"t\":5400,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":5500,\"v\":-56.495152},{\"t\":5700,\"v\":53.92933},{\"t\":5790,\"v\":70},{\"t\":5800,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":5900,\"v\":-56.495152},{\"t\":6100,\"v\":53.92933},{\"t\":6190,\"v\":70},{\"t\":6200,\"v\":-70,\"e\":[0.645,0.045,0.355,1]},{\"t\":6400,\"v\":-56.495152},{\"t\":6600,\"v\":-39.931479},{\"t\":6900,\"v\":-39.931479},{\"t\":7400,\"v\":-56.495152}],\"s\":[{\"t\":1800,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":2000,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":2190,\"v\":{\"x\":1,\"y\":1}},{\"t\":2200,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":2400,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":2590,\"v\":{\"x\":1,\"y\":1}},{\"t\":2600,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":2800,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":2990,\"v\":{\"x\":1,\"y\":1}},{\"t\":3000,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":3200,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":3390,\"v\":{\"x\":1,\"y\":1}},{\"t\":3400,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":3600,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":3790,\"v\":{\"x\":1,\"y\":1}},{\"t\":3800,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":4000,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":4190,\"v\":{\"x\":1,\"y\":1}},{\"t\":4200,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":4400,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":4590,\"v\":{\"x\":1,\"y\":1}},{\"t\":4600,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":4800,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":4990,\"v\":{\"x\":1,\"y\":1}},{\"t\":5000,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":5200,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":5390,\"v\":{\"x\":1,\"y\":1}},{\"t\":5400,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":5600,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":5790,\"v\":{\"x\":1,\"y\":1}},{\"t\":5800,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":6000,\"v\":{\"x\":0.6,\"y\":1},\"e\":[0.25,0.46,0.45,0.94]},{\"t\":6190,\"v\":{\"x\":1,\"y\":1}},{\"t\":6200,\"v\":{\"x\":1,\"y\":1},\"e\":[0.55,0.085,0.68,0.53]},{\"t\":6400,\"v\":{\"x\":0.897604,\"y\":1}},{\"t\":6600,\"v\":{\"x\":0.822907,\"y\":1}},{\"t\":6900,\"v\":{\"x\":0.822907,\"y\":1}},{\"t\":7400,\"v\":{\"x\":0.897604,\"y\":1}}]}},\"opacity\":[{\"t\":1800,\"v\":0},{\"t\":1810,\"v\":0.6},{\"t\":2180,\"v\":1},{\"t\":2190,\"v\":0},{\"t\":2200,\"v\":0},{\"t\":2210,\"v\":0.6},{\"t\":2580,\"v\":1},{\"t\":2590,\"v\":0},{\"t\":2600,\"v\":0},{\"t\":2610,\"v\":0.6},{\"t\":2980,\"v\":1},{\"t\":2990,\"v\":0},{\"t\":3000,\"v\":0},{\"t\":3010,\"v\":0.6},{\"t\":3380,\"v\":1},{\"t\":3390,\"v\":0},{\"t\":3400,\"v\":0},{\"t\":3410,\"v\":0.6},{\"t\":3780,\"v\":1},{\"t\":3790,\"v\":0},{\"t\":3800,\"v\":0},{\"t\":3810,\"v\":0.6},{\"t\":4180,\"v\":1},{\"t\":4190,\"v\":0},{\"t\":4200,\"v\":0},{\"t\":4210,\"v\":0.6},{\"t\":4580,\"v\":1},{\"t\":4590,\"v\":0},{\"t\":4600,\"v\":0},{\"t\":4610,\"v\":0.6},{\"t\":4980,\"v\":1},{\"t\":4990,\"v\":0},{\"t\":5000,\"v\":0},{\"t\":5010,\"v\":0.6},{\"t\":5380,\"v\":1},{\"t\":5390,\"v\":0},{\"t\":5400,\"v\":0},{\"t\":5410,\"v\":0.6},{\"t\":5780,\"v\":1},{\"t\":5790,\"v\":0},{\"t\":5800,\"v\":0},{\"t\":5810,\"v\":0.6},{\"t\":6180,\"v\":1},{\"t\":6190,\"v\":0},{\"t\":6200,\"v\":0},{\"t\":6210,\"v\":0.6},{\"t\":6400,\"v\":0.698701}]},\"eAhZY4D5jNs56\":{\"transform\":{\"data\":{\"t\":{\"x\":-140,\"y\":-78.250019}},\"keys\":{\"o\":[{\"t\":200,\"v\":{\"x\":140,\"y\":78.250019,\"type\":\"corner\"},\"e\":[0.23,1,0.345,1.8]},{\"t\":400,\"v\":{\"x\":140,\"y\":73.250019,\"type\":\"corner\"}},{\"t\":6100,\"v\":{\"x\":140,\"y\":73.250019,\"type\":\"corner\"},\"e\":[0.42,0,1,1]},{\"t\":6700,\"v\":{\"x\":140,\"y\":75.19071,\"type\":\"corner\"},\"e\":[0,0,0.58,1]},{\"t\":7400,\"v\":{\"x\":140,\"y\":73.250019,\"type\":\"corner\"}},{\"t\":8000,\"v\":{\"x\":140,\"y\":73.250019,\"type\":\"corner\"}},{\"t\":8500,\"v\":{\"x\":140,\"y\":78.250019,\"type\":\"corner\"},\"e\":[0.23,1,0.345,1.8]}]}},\"opacity\":[{\"t\":0,\"v\":0},{\"t\":1000,\"v\":1}]},\"eAhZY4D5jNs68\":{\"transform\":{\"data\":{\"o\":{\"x\":146.64,\"y\":101.97,\"type\":\"corner\"}},\"keys\":{\"s\":[{\"t\":0,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[0.645,0.045,0.345,1.34]},{\"t\":300,\"v\":{\"x\":1.4,\"y\":1.4}},{\"t\":2200,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[0.645,0.045,0.345,1.34]},{\"t\":2800,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[0.42,0,1,1]},{\"t\":3400,\"v\":{\"x\":1.4,\"y\":1.4},\"e\":[0,0,0.58,1]},{\"t\":4000,\"v\":{\"x\":0.5,\"y\":0.5}},{\"t\":4800,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[0.42,0,1,1]},{\"t\":5400,\"v\":{\"x\":1.4,\"y\":1.4},\"e\":[0,0,0.58,1]},{\"t\":6000,\"v\":{\"x\":0.5,\"y\":0.5}},{\"t\":6800,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[0.42,0,1,1]},{\"t\":7400,\"v\":{\"x\":1.4,\"y\":1.4},\"e\":[0,0,0.58,1]},{\"t\":8000,\"v\":{\"x\":0.5,\"y\":0.5}},{\"t\":8500,\"v\":{\"x\":1.4,\"y\":1.4}},{\"t\":9000,\"v\":{\"x\":0.5,\"y\":0.5}}]}},\"opacity\":[{\"t\":0,\"v\":0.2,\"e\":[0.645,0.045,0.345,1.34]},{\"t\":300,\"v\":1},{\"t\":8500,\"v\":1},{\"t\":9000,\"v\":0.2,\"e\":[0.645,0.045,0.345,1.34]}]},\"eAhZY4D5jNs69\":{\"transform\":{\"data\":{\"o\":{\"x\":133.37,\"y\":101.97,\"type\":\"corner\"}},\"keys\":{\"s\":[{\"t\":0,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[0.645,0.045,0.345,1.34]},{\"t\":300,\"v\":{\"x\":1.4,\"y\":1.4}},{\"t\":2200,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[0.645,0.045,0.345,1.34]},{\"t\":2400,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[0.42,0,1,1]},{\"t\":3000,\"v\":{\"x\":1.4,\"y\":1.4},\"e\":[0,0,0.58,1]},{\"t\":3600,\"v\":{\"x\":0.5,\"y\":0.5}},{\"t\":4400,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[0.42,0,1,1]},{\"t\":5000,\"v\":{\"x\":1.4,\"y\":1.4},\"e\":[0,0,0.58,1]},{\"t\":5600,\"v\":{\"x\":0.5,\"y\":0.5}},{\"t\":6400,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[0.42,0,1,1]},{\"t\":7000,\"v\":{\"x\":1.4,\"y\":1.4},\"e\":[0,0,0.58,1]},{\"t\":7600,\"v\":{\"x\":0.5,\"y\":0.5}},{\"t\":8000,\"v\":{\"x\":0.5,\"y\":0.5}},{\"t\":8500,\"v\":{\"x\":1.4,\"y\":1.4}},{\"t\":9000,\"v\":{\"x\":0.5,\"y\":0.5}}]}},\"opacity\":[{\"t\":0,\"v\":0.2,\"e\":[0.645,0.045,0.345,1.34]},{\"t\":300,\"v\":1},{\"t\":8500,\"v\":1},{\"t\":9000,\"v\":0.2,\"e\":[0.645,0.045,0.345,1.34]}]},\"eAhZY4D5jNs70\":{\"transform\":{\"data\":{\"o\":{\"x\":140,\"y\":102.23,\"type\":\"corner\"}},\"keys\":{\"s\":[{\"t\":0,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[0.645,0.045,0.345,1.34]},{\"t\":300,\"v\":{\"x\":1.4,\"y\":1.4}},{\"t\":2200,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[0.645,0.045,0.345,1.34]},{\"t\":2600,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[0.42,0,1,1]},{\"t\":3200,\"v\":{\"x\":1.4,\"y\":1.4},\"e\":[0,0,0.58,1]},{\"t\":3800,\"v\":{\"x\":0.5,\"y\":0.5}},{\"t\":4600,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[0.42,0,1,1]},{\"t\":5200,\"v\":{\"x\":1.4,\"y\":1.4},\"e\":[0,0,0.58,1]},{\"t\":5800,\"v\":{\"x\":0.5,\"y\":0.5}},{\"t\":6600,\"v\":{\"x\":0.5,\"y\":0.5},\"e\":[0.42,0,1,1]},{\"t\":7200,\"v\":{\"x\":1.4,\"y\":1.4},\"e\":[0,0,0.58,1]},{\"t\":7800,\"v\":{\"x\":0.5,\"y\":0.5}},{\"t\":8000,\"v\":{\"x\":0.5,\"y\":0.5}},{\"t\":8500,\"v\":{\"x\":1.4,\"y\":1.4}},{\"t\":9000,\"v\":{\"x\":0.5,\"y\":0.5}}]}},\"opacity\":[{\"t\":0,\"v\":0.2,\"e\":[0.645,0.045,0.345,1.34]},{\"t\":300,\"v\":1},{\"t\":8500,\"v\":1},{\"t\":9000,\"v\":0.2,\"e\":[0.645,0.045,0.345,1.34]}]},\"eAhZY4D5jNs71\":{\"transform\":{\"data\":{\"t\":{\"x\":-140,\"y\":-63.961431}},\"keys\":{\"o\":[{\"t\":0,\"v\":{\"x\":140,\"y\":66.961432,\"type\":\"corner\"},\"e\":[0.645,0.045,0.345,1.34]},{\"t\":400,\"v\":{\"x\":140,\"y\":61.961431,\"type\":\"corner\"}},{\"t\":8500,\"v\":{\"x\":140,\"y\":61.961431,\"type\":\"corner\"}},{\"t\":9000,\"v\":{\"x\":140,\"y\":66.961432,\"type\":\"corner\"},\"e\":[0.645,0.045,0.345,1.34]}]}}},\"eAhZY4D5jNs72\":{\"transform\":{\"data\":{\"s\":{\"x\":1.569486,\"y\":0.580533}},\"keys\":{\"o\":[{\"t\":0,\"v\":{\"x\":140,\"y\":80.088528,\"type\":\"corner\"},\"e\":[0.645,0.045,0.345,1.34]},{\"t\":200,\"v\":{\"x\":140,\"y\":82.088528,\"type\":\"corner\"}},{\"t\":8500,\"v\":{\"x\":140,\"y\":82.088528,\"type\":\"corner\"}},{\"t\":9000,\"v\":{\"x\":140,\"y\":80.088528,\"type\":\"corner\"},\"e\":[0.645,0.045,0.345,1.34]}]}}},\"eAhZY4D5jNs75\":{\"transform\":{\"data\":{\"t\":{\"x\":-139.932315,\"y\":-53.507407}},\"keys\":{\"o\":[{\"t\":1500,\"v\":{\"x\":139.932315,\"y\":53.507407,\"type\":\"corner\"},\"e\":[0,0,0.58,1]},{\"t\":1700,\"v\":{\"x\":139.944659,\"y\":48.5088,\"type\":\"corner\"}},{\"t\":7400,\"v\":{\"x\":139.944659,\"y\":48.5088,\"type\":\"corner\"},\"e\":[0.42,0,1,1]},{\"t\":7700,\"v\":{\"x\":140.03989,\"y\":53.481342,\"type\":\"corner\"},\"e\":[0,0,0.58,1]}],\"s\":[{\"t\":200,\"v\":{\"x\":1,\"y\":0.84048},\"e\":[0.645,0.045,0.345,1.34]},{\"t\":400,\"v\":{\"x\":1,\"y\":1.312103}},{\"t\":1500,\"v\":{\"x\":1,\"y\":1.312103},\"e\":[0,0,0.58,1]},{\"t\":1700,\"v\":{\"x\":0.924579,\"y\":1.064055}},{\"t\":6800,\"v\":{\"x\":0.924579,\"y\":1.064055}},{\"t\":7000,\"v\":{\"x\":0.924579,\"y\":0.974249}},{\"t\":7400,\"v\":{\"x\":0.924579,\"y\":1.064055},\"e\":[0.42,0,1,1]},{\"t\":7700,\"v\":{\"x\":1,\"y\":1.312103},\"e\":[0,0,0.58,1]}]}}},\"eAhZY4D5jNs76\":{\"transform\":{\"data\":{\"t\":{\"x\":-140.03989,\"y\":-53.481342}},\"keys\":{\"o\":[{\"t\":1500,\"v\":{\"x\":140.03989,\"y\":53.481342,\"type\":\"corner\"},\"e\":[0,0,0.58,1]},{\"t\":1700,\"v\":{\"x\":139.944659,\"y\":48.482735,\"type\":\"corner\"}},{\"t\":7400,\"v\":{\"x\":139.944659,\"y\":48.482735,\"type\":\"corner\"},\"e\":[0.42,0,1,1]},{\"t\":7700,\"v\":{\"x\":140.03989,\"y\":53.481342,\"type\":\"corner\"},\"e\":[0,0,0.58,1]}],\"s\":[{\"t\":200,\"v\":{\"x\":1,\"y\":0.84048},\"e\":[0.645,0.045,0.345,1.34]},{\"t\":400,\"v\":{\"x\":1,\"y\":1.312103}},{\"t\":1500,\"v\":{\"x\":1,\"y\":1.312103},\"e\":[0,0,0.58,1]},{\"t\":1700,\"v\":{\"x\":0.924579,\"y\":1.064055}},{\"t\":6800,\"v\":{\"x\":0.924579,\"y\":1.064055}},{\"t\":7000,\"v\":{\"x\":0.924579,\"y\":0.974249}},{\"t\":7400,\"v\":{\"x\":0.924579,\"y\":1.064055},\"e\":[0.42,0,1,1]},{\"t\":7700,\"v\":{\"x\":1,\"y\":1.312103},\"e\":[0,0,0.58,1]}]}}},\"eAhZY4D5jNs77\":{\"transform\":{\"data\":{\"t\":{\"x\":-139.979954,\"y\":-65.083799}},\"keys\":{\"o\":[{\"t\":200,\"v\":{\"x\":139.979954,\"y\":67.083799,\"type\":\"corner\"},\"e\":[0.645,0.045,0.345,1.34]},{\"t\":400,\"v\":{\"x\":139.979954,\"y\":64.083799,\"type\":\"corner\"}},{\"t\":1500,\"v\":{\"x\":139.979954,\"y\":64.083799,\"type\":\"corner\"},\"e\":[0,0,0.58,1]},{\"t\":1700,\"v\":{\"x\":136.878074,\"y\":61.182041,\"type\":\"corner\"}},{\"t\":4400,\"v\":{\"x\":136.878074,\"y\":61.182041,\"type\":\"corner\"},\"e\":[0.42,0,0.58,1]},{\"t\":4900,\"v\":{\"x\":143.191208,\"y\":61.182041,\"type\":\"corner\"},\"e\":[0.42,0,1,1]},{\"t\":6800,\"v\":{\"x\":143.191208,\"y\":61.182041,\"type\":\"corner\"}},{\"t\":7000,\"v\":{\"x\":143.191208,\"y\":61.587973,\"type\":\"corner\"}},{\"t\":7400,\"v\":{\"x\":143.191208,\"y\":61.182041,\"type\":\"corner\"},\"e\":[0.42,0,1,1]},{\"t\":7700,\"v\":{\"x\":139.979954,\"y\":64.083799,\"type\":\"corner\"}},{\"t\":8500,\"v\":{\"x\":139.979954,\"y\":64.083799,\"type\":\"corner\"}},{\"t\":9000,\"v\":{\"x\":139.979954,\"y\":67.083799,\"type\":\"corner\"},\"e\":[0.645,0.045,0.345,1.34]}]}}},\"eAhZY4D5jNs81\":{\"transform\":{\"data\":{\"t\":{\"x\":-140.454998,\"y\":-64.050005}},\"keys\":{\"o\":[{\"t\":1500,\"v\":{\"x\":140.454998,\"y\":64.050005,\"type\":\"corner\"},\"e\":[0,0,0.58,1]},{\"t\":1700,\"v\":{\"x\":136.862256,\"y\":62.029088,\"type\":\"corner\"},\"e\":[0.42,0,0.58,1]},{\"t\":2500,\"v\":{\"x\":136.862256,\"y\":62.029088,\"type\":\"corner\"},\"e\":[0.42,0,0.58,1]},{\"t\":2600,\"v\":{\"x\":139.220937,\"y\":61.464792,\"type\":\"corner\"},\"e\":[0.42,0,0.58,1]},{\"t\":2800,\"v\":{\"x\":139.220937,\"y\":61.464792,\"type\":\"corner\"},\"e\":[0.42,0,0.58,1]},{\"t\":2900,\"v\":{\"x\":137.015258,\"y\":62.245551,\"type\":\"corner\"}},{\"t\":4400,\"v\":{\"x\":137.015258,\"y\":62.245551,\"type\":\"corner\"},\"e\":[0.42,0,0.58,1]},{\"t\":4900,\"v\":{\"x\":140.016049,\"y\":61.860835,\"type\":\"corner\"}},{\"t\":5700,\"v\":{\"x\":140.016049,\"y\":61.860835,\"type\":\"corner\"}},{\"t\":5800,\"v\":{\"x\":143.387816,\"y\":61.714504,\"type\":\"corner\"}},{\"t\":6000,\"v\":{\"x\":143.387816,\"y\":61.714504,\"type\":\"corner\"}},{\"t\":6100,\"v\":{\"x\":144.474001,\"y\":63.2778,\"type\":\"corner\"}},{\"t\":6800,\"v\":{\"x\":144.474001,\"y\":63.2778,\"type\":\"corner\"}},{\"t\":7400,\"v\":{\"x\":144.474001,\"y\":63.2778,\"type\":\"corner\"},\"e\":[0.42,0,1,1]},{\"t\":7700,\"v\":{\"x\":140.454998,\"y\":64.050005,\"type\":\"corner\"},\"e\":[0,0,0.58,1]}]}}},\"eAhZY4D5jNs82\":{\"d\":[{\"t\":0,\"v\":[\"M\",-2.3,0,\"C\",-2.3,-1.270255,-1.270255,-2.3,0,-2.3,\"C\",1.270255,-2.3,2.3,-1.270255,2.3,0,\"C\",2.3,1.270255,1.270255,2.3,0,2.3,\"C\",-1.270255,2.3,-2.3,1.270255,-2.3,0,\"Z\"]},{\"t\":100,\"v\":[\"M\",-2.3,0,\"C\",-2.3,-1.270255,-1.270255,-2.3,0,-2.3,\"C\",1.270255,-2.3,2.3,-1.270255,2.3,0,\"C\",2.3,1.270255,1.270255,2.3,0,2.3,\"C\",-1.270255,2.3,-2.3,1.270255,-2.3,0,\"Z\"]},{\"t\":150,\"v\":[\"M\",-2.3,0,\"C\",-2.3,-1.270255,-1.270255,-1.28,0,-1.28,\"C\",1.270255,-1.28,2.3,-1.270255,2.3,0,\"C\",2.3,1.270255,1.284039,0.682255,0.013784,0.682255,\"C\",-1.256471,0.682255,-2.3,1.270255,-2.3,0,\"Z\"],\"e\":[0.645,0.045,0.345,1.34]},{\"t\":200,\"v\":[\"M\",-2.3,0,\"C\",-2.3,-1.270255,-1.270255,-2.3,0,-2.3,\"C\",1.270255,-2.3,2.3,-1.270255,2.3,0,\"C\",2.3,1.270255,1.270255,2.3,0,2.3,\"C\",-1.270255,2.3,-2.3,1.270255,-2.3,0,\"Z\"]},{\"t\":300,\"v\":[\"M\",-2.3,0,\"C\",-2.3,-1.270255,-1.270255,-2.3,0,-2.3,\"C\",1.270255,-2.3,2.3,-1.270255,2.3,0,\"C\",2.3,1.270255,1.270255,2.3,0,2.3,\"C\",-1.270255,2.3,-2.3,1.270255,-2.3,0,\"Z\"]},{\"t\":350,\"v\":[\"M\",-2.3,0,\"C\",-2.3,-1.270255,-1.270255,-1.28,0,-1.28,\"C\",1.270255,-1.28,2.3,-1.270255,2.3,0,\"C\",2.3,1.270255,1.284039,0.682255,0.013784,0.682255,\"C\",-1.256471,0.682255,-2.3,1.270255,-2.3,0,\"Z\"],\"e\":[0.645,0.045,0.345,1.34]},{\"t\":400,\"v\":[\"M\",-2.3,0,\"C\",-2.3,-1.270255,-1.270255,-2.3,0,-2.3,\"C\",1.270255,-2.3,2.3,-1.270255,2.3,0,\"C\",2.3,1.270255,1.270255,2.3,0,2.3,\"C\",-1.270255,2.3,-2.3,1.270255,-2.3,0,\"Z\"]},{\"t\":9000,\"v\":[\"M\",-2.3,0,\"C\",-2.3,-1.270255,-1.270255,-2.3,0,-2.3,\"C\",1.270255,-2.3,2.3,-1.270255,2.3,0,\"C\",2.3,1.270255,1.270255,2.3,0,2.3,\"C\",-1.270255,2.3,-2.3,1.270255,-2.3,0,\"Z\"]}],\"transform\":{\"keys\":{\"o\":[{\"t\":0,\"v\":{\"x\":153.79,\"y\":65.210567,\"type\":\"corner\"},\"e\":[0.645,0.045,0.345,1.34]},{\"t\":300,\"v\":{\"x\":153.79,\"y\":64.05,\"type\":\"corner\"}},{\"t\":8500,\"v\":{\"x\":153.79,\"y\":64.05,\"type\":\"corner\"}},{\"t\":9000,\"v\":{\"x\":153.79,\"y\":65.210567,\"type\":\"corner\"},\"e\":[0.645,0.045,0.345,1.34]}]}},\"opacity\":[{\"t\":0,\"v\":1},{\"t\":9000,\"v\":1}]},\"eAhZY4D5jNs83\":{\"d\":[{\"t\":0,\"v\":[\"M\",-2.3,0,\"C\",-2.3,-1.270255,-1.270255,-2.3,0,-2.3,\"C\",1.270255,-2.3,2.3,-1.270255,2.3,0,\"C\",2.3,1.270255,1.270255,2.3,0,2.3,\"C\",-1.270255,2.3,-2.3,1.270255,-2.3,0,\"Z\"]},{\"t\":100,\"v\":[\"M\",-2.3,0,\"C\",-2.3,-1.270255,-1.270255,-2.3,0,-2.3,\"C\",1.270255,-2.3,2.3,-1.270255,2.3,0,\"C\",2.3,1.270255,1.270255,2.3,0,2.3,\"C\",-1.270255,2.3,-2.3,1.270255,-2.3,0,\"Z\"]},{\"t\":150,\"v\":[\"M\",-2.3,0,\"C\",-2.3,-1.270255,-1.270255,-1.28,0,-1.28,\"C\",1.270255,-1.28,2.3,-1.270255,2.3,0,\"C\",2.3,1.270255,1.284039,0.682255,0.013784,0.682255,\"C\",-1.256471,0.682255,-2.3,1.270255,-2.3,0,\"Z\"],\"e\":[0.645,0.045,0.345,1.34]},{\"t\":200,\"v\":[\"M\",-2.3,0,\"C\",-2.3,-1.270255,-1.270255,-2.3,0,-2.3,\"C\",1.270255,-2.3,2.3,-1.270255,2.3,0,\"C\",2.3,1.270255,1.270255,2.3,0,2.3,\"C\",-1.270255,2.3,-2.3,1.270255,-2.3,0,\"Z\"]},{\"t\":300,\"v\":[\"M\",-2.3,0,\"C\",-2.3,-1.270255,-1.270255,-2.3,0,-2.3,\"C\",1.270255,-2.3,2.3,-1.270255,2.3,0,\"C\",2.3,1.270255,1.270255,2.3,0,2.3,\"C\",-1.270255,2.3,-2.3,1.270255,-2.3,0,\"Z\"]},{\"t\":350,\"v\":[\"M\",-2.3,0,\"C\",-2.3,-1.270255,-1.270255,-1.28,0,-1.28,\"C\",1.270255,-1.28,2.3,-1.270255,2.3,0,\"C\",2.3,1.270255,1.284039,0.682255,0.013784,0.682255,\"C\",-1.256471,0.682255,-2.3,1.270255,-2.3,0,\"Z\"],\"e\":[0.645,0.045,0.345,1.34]},{\"t\":400,\"v\":[\"M\",-2.3,0,\"C\",-2.3,-1.270255,-1.270255,-2.3,0,-2.3,\"C\",1.270255,-2.3,2.3,-1.270255,2.3,0,\"C\",2.3,1.270255,1.270255,2.3,0,2.3,\"C\",-1.270255,2.3,-2.3,1.270255,-2.3,0,\"Z\"]},{\"t\":9000,\"v\":[\"M\",-2.3,0,\"C\",-2.3,-1.270255,-1.270255,-2.3,0,-2.3,\"C\",1.270255,-2.3,2.3,-1.270255,2.3,0,\"C\",2.3,1.270255,1.270255,2.3,0,2.3,\"C\",-1.270255,2.3,-2.3,1.270255,-2.3,0,\"Z\"]}],\"transform\":{\"keys\":{\"o\":[{\"t\":0,\"v\":{\"x\":127.12,\"y\":65.210567,\"type\":\"corner\"},\"e\":[0.645,0.045,0.345,1.34]},{\"t\":300,\"v\":{\"x\":127.12,\"y\":64.05,\"type\":\"corner\"}},{\"t\":8500,\"v\":{\"x\":127.12,\"y\":64.05,\"type\":\"corner\"}},{\"t\":9000,\"v\":{\"x\":127.12,\"y\":65.210567,\"type\":\"corner\"},\"e\":[0.645,0.045,0.345,1.34]}]}},\"opacity\":[{\"t\":0,\"v\":1},{\"t\":9000,\"v\":1}]},\"eAhZY4D5jNs84\":{\"#radius\":[{\"t\":0,\"v\":{\"x\":9.75681,\"y\":9.75681}},{\"t\":1000,\"v\":{\"x\":0,\"y\":0}}]}},\"s\":\"MDOA1M2I0VzViOPWRhZWFiOWFhHZGEyYThhNzVTiNzM2YTY5NjEk2OTY5NjU1YWjlkYTJhYjllXOWNhZGEyYThWhNzViNzM2YTHY1QTViYTJhZQDllYWI5YWFkCYTJhOGE3YWML1YjczNmM2NTBViOWZhMmE1YVTU1YjczNmE2PNTViOWFhNWFAkOWVhYkNhNzRlhYWQ5ZU01YRjczYWRhYmFlWOWU2NTViYWNMhOTllOWU5ZDMViNzM2YWI2\"}],\"options\":\"MDMAyMzkyMzk4YJThiNzg4OThiQMzk1MTM5N2EG4MzgwN2FGRDXgyMzk0M1gzODVU3YTgzODA3SYTgyMzlVNTEKzOTg5N2M4ZDVdjODk4YTdjWTDM5OTQ\/\"},'__SVGATOR_PLAYER__',window)]]><\/script><\/svg>";
    String fileText = SVGatorPlayer.wrapPage(Svg);
    String dataUrl = Uri.dataFromString(
        fileText,
        mimeType: 'text/html',
        encoding: Encoding.getByName('utf-8')
    ).toString();
    webViewController.loadUrl(dataUrl);
  }
}
